@@ -537,14 +537,6 @@ ogs_slice_data_t *ogs_slice_find_by_s_nssai(
         }
     }
 
-    /* Compare Only SST if DefaultSingleNSSAI */
-    for (i = 0; i < num_of_slice_data; i++) {
-        if (slice_data[i].default_indicator == true &&
-            s_nssai->sst == slice_data[i].s_nssai.sst) {
-            return slice_data + i;
-        }
-    }
-
     return NULL;
 }
 
@@ -566,6 +558,8 @@ void ogs_subscription_data_free(ogs_subscription_data_t *subscription_data)
     }
 
     subscription_data->num_of_slice = 0;
+
+    subscription_data->num_of_msisdn = 0;
 }
 
 void ogs_session_data_free(ogs_session_data_t *session_data)
