@@ -412,7 +412,7 @@ for (k, v) in sorted_type_list:
             f.write("    uint16_t size = 3;\n\n")
         else:
             f.write("    uint16_t size = sizeof(ogs_nas_%s_t);\n\n" % v_lower(k))
-        f.write("    ogs_assert(ogs_pkbuf_pull(pkbuf, size));\n")
+        f.write("    if (ogs_pkbuf_pull(pkbuf, size) == NULL) return -1;\n")
         f.write("    memcpy(%s, pkbuf->data - size, size);\n\n" % get_value(k))
         if "decode" in type_list[k]:
             f.write("%s" % type_list[k]["decode"])
@@ -443,7 +443,7 @@ for (k, v) in sorted_type_list:
         f.write("    ogs_nas_%s_t *source = (ogs_nas_%s_t *)pkbuf->data;\n\n" % (v_lower(k), v_lower(k)))
         f.write("    %s->length = be16toh(source->length);\n" % get_value(k))
         f.write("    size = %s->length + sizeof(%s->length);\n\n" % (get_value(k), get_value(k)))
-        f.write("    ogs_assert(ogs_pkbuf_pull(pkbuf, size));\n")
+        f.write("    if (ogs_pkbuf_pull(pkbuf, size) == NULL) return -1;\n")
         f.write("    %s->buffer = pkbuf->data - size + sizeof(%s->length);\n\n" % (get_value(k), get_value(k)))
         f.write("    ogs_trace(\"  %s - \");\n" % v_upper(k))
         f.write("    ogs_log_hexdump(OGS_LOG_TRACE, (void*)%s->buffer, %s->length);\n\n" % (get_value(k), get_value(k)));
@@ -473,7 +473,8 @@ for (k, v) in sorted_type_list:
         f.write("    ogs_nas_%s_t *source = (ogs_nas_%s_t *)pkbuf->data;\n\n" % (v_lower(k), v_lower(k)))
         f.write("    %s->length = source->length;\n" % get_value(k))
         f.write("    size = %s->length + sizeof(%s->length);\n\n" % (get_value(k), get_value(k)))
-        f.write("    ogs_assert(ogs_pkbuf_pull(pkbuf, size));\n")
+        f.write("    if (ogs_pkbuf_pull(pkbuf, size) == NULL) return -1;\n")
+        f.write("    if (sizeof(*%s) < size) return -1;\n" % get_value(k))
         f.write("    memcpy(%s, pkbuf->data - size, size);\n\n" % get_value(k))
         if "decode" in type_list[k]:
             f.write("%s" % type_list[k]["decode"])
@@ -662,7 +663,7 @@ for (k, v) in sorted_msg_list:
 
     for ie in [ies for ies in msg_list[k]["ies"] if ies["presence"] == "M"]:
         f.write("    size = ogs_nas_5gs_decode_%s(&%s->%s, pkbuf);\n" % (v_lower(ie["type"]), get_value(k), get_value(ie["value"])))
-        f.write("    ogs_assert(size >= 0);\n")
+        f.write("    if (size < 0) return size;\n")
         f.write("    decoded += size;\n\n")
 
     optional_fields = False;
@@ -685,7 +686,7 @@ for (k, v) in sorted_msg_list:
             f.write("            decoded--;\n")
             f.write("            ogs_assert(ogs_pkbuf_push(pkbuf, 1));\n")
         f.write("            size = ogs_nas_5gs_decode_%s(&%s->%s, pkbuf);\n" % (v_lower(ie["type"]), get_value(k), get_value(ie["value"])))
-        f.write("            ogs_assert(size >= 0);\n")
+        f.write("            if (size < 0) return size;\n")
         f.write("            %s->presencemask |= OGS_NAS_5GS_%s_%s_PRESENT;\n" % (get_value(k), v_upper(k), v_upper(ie["value"])))
         f.write("            decoded += size;\n")
         f.write("            break;\n")
@@ -715,7 +716,7 @@ f.write("""int ogs_nas_5gmm_decode(ogs_nas_5gs_message_t *message, ogs_pkbuf_t *
     memset(message, 0, sizeof(ogs_nas_5gs_message_t));
 
     size = sizeof(ogs_nas_5gmm_header_t);
-    ogs_assert(ogs_pkbuf_pull(pkbuf, size));
+    if (ogs_pkbuf_pull(pkbuf, size) == NULL) return OGS_ERROR;
     memcpy(&message->gmm.h, pkbuf->data - size, size);
     decoded += size;
 
@@ -728,7 +729,7 @@ for (k, v) in sorted_msg_list:
         f.write("    case OGS_NAS_5GS_%s:\n" % v_upper(k))
         if len(msg_list[k]["ies"]) != 0:
             f.write("        size = ogs_nas_5gs_decode_%s(message, pkbuf);\n" % v_lower(k))
-            f.write("        ogs_assert(size >= 0);\n")
+            f.write("        if (size < 0) return OGS_ERROR;\n")
             f.write("        decoded += size;\n")
         f.write("        break;\n")
 
@@ -756,7 +757,7 @@ f.write("""int ogs_nas_5gsm_decode(ogs_nas_5gs_message_t *message, ogs_pkbuf_t *
     memset(message, 0, sizeof(ogs_nas_5gs_message_t));
 
     size = sizeof(ogs_nas_5gsm_header_t);
-    ogs_assert(ogs_pkbuf_pull(pkbuf, size));
+    if (ogs_pkbuf_pull(pkbuf, size) == NULL) return OGS_ERROR;
     memcpy(&message->gsm.h, pkbuf->data - size, size);
     decoded += size;
 
@@ -769,7 +770,7 @@ for (k, v) in sorted_msg_list:
         f.write("    case OGS_NAS_5GS_%s:\n" % v_upper(k))
         if len(msg_list[k]["ies"]) != 0:
             f.write("        size = ogs_nas_5gs_decode_%s(message, pkbuf);\n" % v_lower(k))
-            f.write("        ogs_assert(size >= 0);\n")
+            f.write("        if (size < 0) return OGS_ERROR;\n")
             f.write("        decoded += size;\n")
         f.write("        break;\n")
 
