@@ -20,10 +20,11 @@
 #include "app/ogs-app.h"
 #include "ogs-pfcp.h"
 
+int __ogs_pfcp_domain;
 static ogs_pfcp_context_t self;
+static int context_initialized = 0;
 
 static OGS_POOL(ogs_pfcp_node_pool, ogs_pfcp_node_t);
-static OGS_POOL(ogs_pfcp_gtpu_resource_pool, ogs_pfcp_gtpu_resource_t);
 
 static OGS_POOL(ogs_pfcp_sess_pool, ogs_pfcp_sess_t);
 static OGS_POOL(ogs_pfcp_pdr_pool, ogs_pfcp_pdr_t);
@@ -36,9 +37,7 @@ static OGS_POOL(ogs_pfcp_dev_pool, ogs_pfcp_dev_t);
 static OGS_POOL(ogs_pfcp_subnet_pool, ogs_pfcp_subnet_t);
 static OGS_POOL(ogs_pfcp_rule_pool, ogs_pfcp_rule_t);
 
-static int context_initialized = 0;
-
-void ogs_pfcp_context_init(int num_of_gtpu_resource)
+void ogs_pfcp_context_init(void)
 {
     struct timeval tv;
     ogs_assert(context_initialized == 0);
@@ -65,10 +64,6 @@ void ogs_pfcp_context_init(int num_of_gtpu_resource)
     ogs_log_install_domain(&__ogs_pfcp_domain, "pfcp", ogs_core()->log.level);
 
     ogs_pool_init(&ogs_pfcp_node_pool, ogs_app()->pool.pfcp_node);
-    ogs_pool_init(&ogs_pfcp_gtpu_resource_pool, num_of_gtpu_resource);
-
-    ogs_list_init(&self.peer_list);
-    ogs_list_init(&self.gtpu_resource_list);
 
     ogs_pool_init(&ogs_pfcp_sess_pool, ogs_app()->pool.sess);
 
@@ -86,13 +81,12 @@ void ogs_pfcp_context_init(int num_of_gtpu_resource)
     ogs_pool_init(&ogs_pfcp_rule_pool,
             ogs_app()->pool.sess * OGS_MAX_NUM_OF_RULE);
 
-    ogs_list_init(&self.dev_list);
     ogs_pool_init(&ogs_pfcp_dev_pool, OGS_MAX_NUM_OF_DEV);
-    ogs_list_init(&self.subnet_list);
     ogs_pool_init(&ogs_pfcp_subnet_pool, OGS_MAX_NUM_OF_SUBNET);
 
-    self.pdr_hash = ogs_hash_make();
-    self.far_hash = ogs_hash_make();
+    self.object_teid_hash = ogs_hash_make();
+    self.far_f_teid_hash = ogs_hash_make();
+    self.far_teid_hash = ogs_hash_make();
 
     context_initialized = 1;
 }
@@ -101,10 +95,12 @@ void ogs_pfcp_context_final(void)
 {
     ogs_assert(context_initialized == 1);
 
-    ogs_assert(self.pdr_hash);
-    ogs_hash_destroy(self.pdr_hash);
-    ogs_assert(self.far_hash);
-    ogs_hash_destroy(self.far_hash);
+    ogs_assert(self.object_teid_hash);
+    ogs_hash_destroy(self.object_teid_hash);
+    ogs_assert(self.far_f_teid_hash);
+    ogs_hash_destroy(self.far_f_teid_hash);
+    ogs_assert(self.far_teid_hash);
+    ogs_hash_destroy(self.far_teid_hash);
 
     ogs_pfcp_dev_remove_all();
     ogs_pfcp_subnet_remove_all();
@@ -120,11 +116,9 @@ void ogs_pfcp_context_final(void)
     ogs_pool_final(&ogs_pfcp_qer_pool);
     ogs_pool_final(&ogs_pfcp_bar_pool);
 
-    ogs_pfcp_node_remove_all(&self.peer_list);
-    ogs_pfcp_gtpu_resource_remove_all(&self.gtpu_resource_list);
+    ogs_pfcp_node_remove_all(&self.pfcp_peer_list);
 
     ogs_pool_final(&ogs_pfcp_node_pool);
-    ogs_pool_final(&ogs_pfcp_gtpu_resource_pool);
 
     context_initialized = 0;
 }
@@ -137,6 +131,7 @@ ogs_pfcp_context_t *ogs_pfcp_self(void)
 static int ogs_pfcp_context_prepare(void)
 {
     self.pfcp_port = OGS_PFCP_UDP_PORT;
+
     self.tun_ifname = "ogstun";
 
     return OGS_OK;
@@ -211,7 +206,7 @@ int ogs_pfcp_context_parse_config(const char *local, const char *remote)
                                     family != AF_INET && family != AF_INET6) {
                                     ogs_warn("Ignore family(%d) : "
                                         "AF_UNSPEC(%d), "
-                                        "AF_INET(%d), AF_INET6(%d) ", 
+                                        "AF_INET(%d), AF_INET6(%d) ",
                                         family, AF_UNSPEC, AF_INET, AF_INET6);
                                     family = AF_UNSPEC;
                                 }
@@ -231,8 +226,8 @@ int ogs_pfcp_context_parse_config(const char *local, const char *remote)
                                             break;
                                     }
 
-                                    ogs_assert(num <= OGS_MAX_NUM_OF_HOSTNAME);
-                                    hostname[num++] = 
+                                    ogs_assert(num < OGS_MAX_NUM_OF_HOSTNAME);
+                                    hostname[num++] =
                                         ogs_yaml_iter_value(&hostname_iter);
                                 } while (
                                     ogs_yaml_iter_type(&hostname_iter) ==
@@ -245,7 +240,8 @@ int ogs_pfcp_context_parse_config(const char *local, const char *remote)
                                 }
                             } else if (!strcmp(pfcp_key, "dev")) {
                                 dev = ogs_yaml_iter_value(&pfcp_iter);
-                            } else if (!strcmp(pfcp_key, "apn")) {
+                            } else if (!strcmp(pfcp_key, "apn") ||
+                                        !strcmp(pfcp_key, "dnn")) {
                                 /* Skip */
                             } else
                                 ogs_warn("unknown key `%s`", pfcp_key);
@@ -291,55 +287,57 @@ int ogs_pfcp_context_parse_config(const char *local, const char *remote)
                                 NULL, self.pfcp_port);
                         ogs_assert(rv == OGS_OK);
                     }
-                } else if (!strcmp(local_key, "pdn")) {
-                    ogs_yaml_iter_t pdn_array, pdn_iter;
-                    ogs_yaml_iter_recurse(&local_iter, &pdn_array);
+                } else if (!strcmp(local_key, "subnet")) {
+                    ogs_yaml_iter_t subnet_array, subnet_iter;
+                    ogs_yaml_iter_recurse(&local_iter, &subnet_array);
 
                     do {
                         ogs_pfcp_subnet_t *subnet = NULL;
                         const char *ipstr = NULL;
                         const char *mask_or_numbits = NULL;
-                        const char *apn = NULL;
+                        const char *dnn = NULL;
                         const char *dev = self.tun_ifname;
-                        const char *low[MAX_NUM_OF_SUBNET_RANGE];
-                        const char *high[MAX_NUM_OF_SUBNET_RANGE];
+                        const char *low[OGS_MAX_NUM_OF_SUBNET_RANGE];
+                        const char *high[OGS_MAX_NUM_OF_SUBNET_RANGE];
                         int i, num = 0;
 
-                        if (ogs_yaml_iter_type(&pdn_array) ==
+                        if (ogs_yaml_iter_type(&subnet_array) ==
                                 YAML_MAPPING_NODE) {
-                            memcpy(&pdn_iter, &pdn_array,
+                            memcpy(&subnet_iter, &subnet_array,
                                     sizeof(ogs_yaml_iter_t));
-                        } else if (ogs_yaml_iter_type(&pdn_array) ==
+                        } else if (ogs_yaml_iter_type(&subnet_array) ==
                                 YAML_SEQUENCE_NODE) {
-                            if (!ogs_yaml_iter_next(&pdn_array))
+                            if (!ogs_yaml_iter_next(&subnet_array))
                                 break;
-                            ogs_yaml_iter_recurse(&pdn_array, &pdn_iter);
-                        } else if (ogs_yaml_iter_type(&pdn_array) ==
+                            ogs_yaml_iter_recurse(&subnet_array, &subnet_iter);
+                        } else if (ogs_yaml_iter_type(&subnet_array) ==
                                 YAML_SCALAR_NODE) {
                             break;
                         } else
                             ogs_assert_if_reached();
 
-                        while (ogs_yaml_iter_next(&pdn_iter)) {
-                            const char *pdn_key = ogs_yaml_iter_key(&pdn_iter);
-                            ogs_assert(pdn_key);
-                            if (!strcmp(pdn_key, "addr")) {
+                        while (ogs_yaml_iter_next(&subnet_iter)) {
+                            const char *subnet_key =
+                                ogs_yaml_iter_key(&subnet_iter);
+                            ogs_assert(subnet_key);
+                            if (!strcmp(subnet_key, "addr")) {
                                 char *v =
-                                    (char *)ogs_yaml_iter_value(&pdn_iter);
+                                    (char *)ogs_yaml_iter_value(&subnet_iter);
                                 if (v) {
                                     ipstr = (const char *)strsep(&v, "/");
                                     if (ipstr) {
                                         mask_or_numbits = (const char *)v;
                                     }
                                 }
-                            } else if (!strcmp(pdn_key, "apn") ||
-                                        !strcmp(pdn_key, "dnn")) {
-                                apn = ogs_yaml_iter_value(&pdn_iter);
-                            } else if (!strcmp(pdn_key, "dev")) {
-                                dev = ogs_yaml_iter_value(&pdn_iter);
-                            } else if (!strcmp(pdn_key, "range")) {
+                            } else if (!strcmp(subnet_key, "apn") ||
+                                        !strcmp(subnet_key, "dnn")) {
+                                dnn = ogs_yaml_iter_value(&subnet_iter);
+                            } else if (!strcmp(subnet_key, "dev")) {
+                                dev = ogs_yaml_iter_value(&subnet_iter);
+                            } else if (!strcmp(subnet_key, "range")) {
                                 ogs_yaml_iter_t range_iter;
-                                ogs_yaml_iter_recurse(&pdn_iter, &range_iter);
+                                ogs_yaml_iter_recurse(
+                                        &subnet_iter, &range_iter);
                                 ogs_assert(ogs_yaml_iter_type(&range_iter) !=
                                     YAML_MAPPING_NODE);
                                 do {
@@ -354,8 +352,8 @@ int ogs_pfcp_context_parse_config(const char *local, const char *remote)
                                     v = (char *)
                                         ogs_yaml_iter_value(&range_iter);
                                     if (v) {
-                                        ogs_assert(num <=
-                                                MAX_NUM_OF_SUBNET_RANGE);
+                                        ogs_assert(num <
+                                                OGS_MAX_NUM_OF_SUBNET_RANGE);
                                         low[num] =
                                             (const char *)strsep(&v, "-");
                                         if (low[num] && strlen(low[num]) == 0)
@@ -371,11 +369,11 @@ int ogs_pfcp_context_parse_config(const char *local, const char *remote)
                                     ogs_yaml_iter_type(&range_iter) ==
                                     YAML_SEQUENCE_NODE);
                             } else
-                                ogs_warn("unknown key `%s`", pdn_key);
+                                ogs_warn("unknown key `%s`", subnet_key);
                         }
 
                         subnet = ogs_pfcp_subnet_add(
-                                ipstr, mask_or_numbits, apn, dev);
+                                ipstr, mask_or_numbits, dnn, dev);
                         ogs_assert(subnet);
 
                         subnet->num_of_range = num;
@@ -384,7 +382,7 @@ int ogs_pfcp_context_parse_config(const char *local, const char *remote)
                             subnet->range[i].high = high[i];
                         }
 
-                    } while (ogs_yaml_iter_type(&pdn_array) ==
+                    } while (ogs_yaml_iter_type(&subnet_array) ==
                             YAML_SEQUENCE_NODE);
                 }
             }
@@ -406,8 +404,8 @@ int ogs_pfcp_context_parse_config(const char *local, const char *remote)
                         uint16_t port = self.pfcp_port;
                         uint16_t tac[OGS_MAX_NUM_OF_TAI] = {0,};
                         uint8_t num_of_tac = 0;
-                        const char *apn[OGS_MAX_NUM_OF_APN];
-                        uint8_t num_of_apn = 0;
+                        const char *dnn[OGS_MAX_NUM_OF_DNN];
+                        uint8_t num_of_dnn = 0;
                         uint32_t e_cell_id[OGS_MAX_NUM_OF_CELL_ID] = {0,};
                         uint8_t num_of_e_cell_id = 0;
                         uint64_t nr_cell_id[OGS_MAX_NUM_OF_CELL_ID] = {0,};
@@ -442,7 +440,7 @@ int ogs_pfcp_context_parse_config(const char *local, const char *remote)
                                     family != AF_INET && family != AF_INET6) {
                                     ogs_warn("Ignore family(%d) : "
                                         "AF_UNSPEC(%d), "
-                                        "AF_INET(%d), AF_INET6(%d) ", 
+                                        "AF_INET(%d), AF_INET6(%d) ",
                                         family, AF_UNSPEC, AF_INET, AF_INET6);
                                     family = AF_UNSPEC;
                                 }
@@ -461,8 +459,8 @@ int ogs_pfcp_context_parse_config(const char *local, const char *remote)
                                             break;
                                     }
 
-                                    ogs_assert(num <= OGS_MAX_NUM_OF_HOSTNAME);
-                                    hostname[num++] = 
+                                    ogs_assert(num < OGS_MAX_NUM_OF_HOSTNAME);
+                                    hostname[num++] =
                                         ogs_yaml_iter_value(&hostname_iter);
                                 } while (
                                     ogs_yaml_iter_type(&hostname_iter) ==
@@ -479,7 +477,7 @@ int ogs_pfcp_context_parse_config(const char *local, const char *remote)
                                 do {
                                     const char *v = NULL;
 
-                                    ogs_assert(num_of_tac <=
+                                    ogs_assert(num_of_tac <
                                             OGS_MAX_NUM_OF_TAI);
                                     if (ogs_yaml_iter_type(&tac_iter) ==
                                             YAML_SEQUENCE_NODE) {
@@ -497,29 +495,29 @@ int ogs_pfcp_context_parse_config(const char *local, const char *remote)
                                         YAML_SEQUENCE_NODE);
                             } else if (!strcmp(pfcp_key, "apn") ||
                                         !strcmp(pfcp_key, "dnn")) {
-                                ogs_yaml_iter_t apn_iter;
-                                ogs_yaml_iter_recurse(&pfcp_iter, &apn_iter);
-                                ogs_assert(ogs_yaml_iter_type(&apn_iter) !=
+                                ogs_yaml_iter_t dnn_iter;
+                                ogs_yaml_iter_recurse(&pfcp_iter, &dnn_iter);
+                                ogs_assert(ogs_yaml_iter_type(&dnn_iter) !=
                                     YAML_MAPPING_NODE);
 
                                 do {
                                     const char *v = NULL;
 
-                                    ogs_assert(num_of_apn <=
-                                            OGS_MAX_NUM_OF_APN);
-                                    if (ogs_yaml_iter_type(&apn_iter) ==
+                                    ogs_assert(num_of_dnn <
+                                            OGS_MAX_NUM_OF_DNN);
+                                    if (ogs_yaml_iter_type(&dnn_iter) ==
                                             YAML_SEQUENCE_NODE) {
-                                        if (!ogs_yaml_iter_next(&apn_iter))
+                                        if (!ogs_yaml_iter_next(&dnn_iter))
                                             break;
                                     }
 
-                                    v = ogs_yaml_iter_value(&apn_iter);
+                                    v = ogs_yaml_iter_value(&dnn_iter);
                                     if (v) {
-                                        apn[num_of_apn] = v;
-                                        num_of_apn++;
+                                        dnn[num_of_dnn] = v;
+                                        num_of_dnn++;
                                     }
                                 } while (
-                                    ogs_yaml_iter_type(&apn_iter) ==
+                                    ogs_yaml_iter_type(&dnn_iter) ==
                                         YAML_SEQUENCE_NODE);
                             } else if (!strcmp(pfcp_key, "e_cell_id")) {
                                 ogs_yaml_iter_t e_cell_id_iter;
@@ -531,7 +529,7 @@ int ogs_pfcp_context_parse_config(const char *local, const char *remote)
                                 do {
                                     const char *v = NULL;
 
-                                    ogs_assert(num_of_e_cell_id <= 
+                                    ogs_assert(num_of_e_cell_id <
                                             OGS_MAX_NUM_OF_ENB_ID);
                                     if (ogs_yaml_iter_type(&e_cell_id_iter) ==
                                             YAML_SEQUENCE_NODE) {
@@ -543,7 +541,7 @@ int ogs_pfcp_context_parse_config(const char *local, const char *remote)
                                     v = ogs_yaml_iter_value(&e_cell_id_iter);
                                     if (v) {
                                         e_cell_id[num_of_e_cell_id]
-                                            = ogs_uint28_from_string((char*)v);
+                                            = ogs_uint64_from_string((char*)v);
                                         num_of_e_cell_id++;
                                     }
                                 } while (
@@ -559,7 +557,7 @@ int ogs_pfcp_context_parse_config(const char *local, const char *remote)
                                 do {
                                     const char *v = NULL;
 
-                                    ogs_assert(num_of_nr_cell_id <=
+                                    ogs_assert(num_of_nr_cell_id <
                                             OGS_MAX_NUM_OF_ENB_ID);
                                     if (ogs_yaml_iter_type(&nr_cell_id_iter) ==
                                             YAML_SEQUENCE_NODE) {
@@ -571,7 +569,7 @@ int ogs_pfcp_context_parse_config(const char *local, const char *remote)
                                     v = ogs_yaml_iter_value(&nr_cell_id_iter);
                                     if (v) {
                                         nr_cell_id[num_of_nr_cell_id]
-                                            = ogs_uint36_from_string((char*)v);
+                                            = ogs_uint64_from_string((char*)v);
                                         num_of_nr_cell_id++;
                                     }
                                 } while (
@@ -600,15 +598,15 @@ int ogs_pfcp_context_parse_config(const char *local, const char *remote)
 
                         node = ogs_pfcp_node_new(addr);
                         ogs_assert(node);
-                        ogs_list_add(&self.peer_list, node);
+                        ogs_list_add(&self.pfcp_peer_list, node);
 
                         node->num_of_tac = num_of_tac;
                         if (num_of_tac != 0)
                             memcpy(node->tac, tac, sizeof(node->tac));
 
-                        node->num_of_apn = num_of_apn;
-                        if (num_of_apn != 0)
-                            memcpy(node->apn, apn, sizeof(node->apn));
+                        node->num_of_dnn = num_of_dnn;
+                        if (num_of_dnn != 0)
+                            memcpy(node->dnn, dnn, sizeof(node->dnn));
                         
                         node->num_of_e_cell_id = num_of_e_cell_id;
                         if (num_of_e_cell_id != 0)
@@ -658,7 +656,7 @@ void ogs_pfcp_node_free(ogs_pfcp_node_t *node)
 {
     ogs_assert(node);
 
-    ogs_pfcp_gtpu_resource_remove_all(&node->gtpu_resource_list);
+    ogs_gtpu_resource_remove_all(&node->gtpu_resource_list);
 
     if (node->sock)
         ogs_sock_destroy(node->sock);
@@ -724,28 +722,10 @@ void ogs_pfcp_node_remove_all(ogs_list_t *list)
         ogs_pfcp_node_remove(list, node);
 }
 
-ogs_pfcp_gtpu_resource_t *ogs_pfcp_gtpu_resource_add(ogs_list_t *list,
-        ogs_pfcp_user_plane_ip_resource_info_t *info)
+ogs_gtpu_resource_t *ogs_pfcp_find_gtpu_resource(ogs_list_t *list,
+        char *dnn, ogs_pfcp_interface_t source_interface)
 {
-    ogs_pfcp_gtpu_resource_t *resource = NULL;
-
-    ogs_assert(list);
-    ogs_assert(info);
-
-    ogs_pool_alloc(&ogs_pfcp_gtpu_resource_pool, &resource);
-    ogs_assert(resource);
-
-    memcpy(&resource->info, info, sizeof(*info));
-
-    ogs_list_add(list, resource);
-
-    return resource;
-}
-
-ogs_pfcp_gtpu_resource_t *ogs_pfcp_gtpu_resource_find(ogs_list_t *list,
-        char *apn, ogs_pfcp_interface_t source_interface)
-{
-    ogs_pfcp_gtpu_resource_t *resource = NULL;
+    ogs_gtpu_resource_t *resource = NULL;
 
     ogs_assert(list);
 
@@ -754,8 +734,8 @@ ogs_pfcp_gtpu_resource_t *ogs_pfcp_gtpu_resource_find(ogs_list_t *list,
 
         if (resource->info.assoni &&
             strlen(resource->info.network_instance) &&
-            apn && strlen(apn) &&
-            ogs_strcasecmp(apn, resource->info.network_instance) != 0) {
+            dnn && strlen(dnn) &&
+            ogs_strcasecmp(dnn, resource->info.network_instance) != 0) {
             match = false;
         }
 
@@ -772,38 +752,58 @@ ogs_pfcp_gtpu_resource_t *ogs_pfcp_gtpu_resource_find(ogs_list_t *list,
     return NULL;
 }
 
-void ogs_pfcp_gtpu_resource_remove(ogs_list_t *list,
-        ogs_pfcp_gtpu_resource_t *resource)
+void ogs_pfcp_setup_far_gtpu_node(ogs_pfcp_far_t *far)
 {
-    ogs_assert(list);
-    ogs_assert(resource);
+    int rv;
+    ogs_ip_t ip;
+    ogs_gtp_node_t *gnode = NULL;
 
-    ogs_list_remove(list, resource);
+    ogs_assert(far);
 
-    ogs_pool_free(&ogs_pfcp_gtpu_resource_pool, resource);
+    ogs_pfcp_outer_header_creation_to_ip(&far->outer_header_creation, &ip);
+
+    /* No Outer Header Creation */
+    if (ip.len == 0) return;
+
+    gnode = ogs_gtp_node_find_by_ip(&ogs_gtp_self()->gtpu_peer_list, &ip);
+    if (!gnode) {
+        gnode = ogs_gtp_node_add_by_ip(
+            &ogs_gtp_self()->gtpu_peer_list, &ip, ogs_gtp_self()->gtpu_port);
+        ogs_assert(gnode);
+
+        rv = ogs_gtp_connect(
+                ogs_gtp_self()->gtpu_sock, ogs_gtp_self()->gtpu_sock6, gnode);
+        ogs_assert(rv == OGS_OK);
+    }
+
+    OGS_SETUP_GTP_NODE(far, gnode);
 }
 
-void ogs_pfcp_gtpu_resource_remove_all(ogs_list_t *list)
+void ogs_pfcp_setup_pdr_gtpu_node(ogs_pfcp_pdr_t *pdr)
 {
-    ogs_pfcp_gtpu_resource_t *resource = NULL, *next_resource = NULL;
+    int rv;
+    ogs_ip_t ip;
+    ogs_gtp_node_t *gnode = NULL;
 
-    ogs_assert(list);
+    ogs_assert(pdr);
 
-    ogs_list_for_each_safe(list, next_resource, resource)
-        ogs_pfcp_gtpu_resource_remove(list, resource);
-}
+    /* No F-TEID */
+    if (pdr->f_teid_len == 0) return;
 
-ogs_pfcp_pdr_t *ogs_pfcp_sess_default_pdr(
-        ogs_pfcp_sess_t *sess, ogs_pfcp_interface_t src_if)
-{
-    ogs_pfcp_pdr_t *pdr = NULL;
+    ogs_pfcp_f_teid_to_ip(&pdr->f_teid, &ip);
 
-    ogs_assert(sess);
+    gnode = ogs_gtp_node_find_by_ip(&ogs_gtp_self()->gtpu_peer_list, &ip);
+    if (!gnode) {
+        gnode = ogs_gtp_node_add_by_ip(
+            &ogs_gtp_self()->gtpu_peer_list, &ip, ogs_gtp_self()->gtpu_port);
+        ogs_assert(gnode);
 
-    for (pdr = ogs_list_last(&sess->pdr_list); pdr; pdr = ogs_list_prev(pdr))
-        if (pdr->src_if == src_if) return pdr;
+        rv = ogs_gtp_connect(
+                ogs_gtp_self()->gtpu_sock, ogs_gtp_self()->gtpu_sock6, gnode);
+        ogs_assert(rv == OGS_OK);
+    }
 
-    return NULL;
+    OGS_SETUP_GTP_NODE(pdr, gnode);
 }
 
 void ogs_pfcp_sess_clear(ogs_pfcp_sess_t *sess)
@@ -835,6 +835,8 @@ ogs_pfcp_pdr_t *ogs_pfcp_pdr_add(ogs_pfcp_sess_t *sess)
     ogs_assert(pdr);
     memset(pdr, 0, sizeof *pdr);
 
+    pdr->obj.type = OGS_PFCP_OBJ_PDR_TYPE;
+
     pdr->index = ogs_pool_index(&ogs_pfcp_pdr_pool, pdr);
     ogs_assert(pdr->index > 0 &&
             pdr->index <= ogs_app()->pool.sess * OGS_MAX_NUM_OF_PDR);
@@ -845,6 +847,8 @@ ogs_pfcp_pdr_t *ogs_pfcp_pdr_add(ogs_pfcp_sess_t *sess)
     pdr->id = *(pdr->id_node);
     ogs_assert(pdr->id > 0 && pdr->id <= OGS_MAX_NUM_OF_PDR);
 
+    pdr->src_if = OGS_PFCP_INTERFACE_UNKNOWN;
+
     pdr->sess = sess;
     ogs_list_add(&sess->pdr_list, pdr);
 
@@ -881,30 +885,53 @@ ogs_pfcp_pdr_t *ogs_pfcp_pdr_find_or_add(
     return pdr;
 }
 
-static uint64_t pdr_hash_keygen(uint32_t teid, uint8_t qfi)
-{
-    uint64_t hashkey = (teid << 8) + qfi;
-    return hashkey;
-}
-
-void ogs_pfcp_pdr_hash_set(ogs_pfcp_pdr_t *pdr)
+void ogs_pfcp_object_teid_hash_set(
+        ogs_pfcp_object_type_e type, ogs_pfcp_pdr_t *pdr)
 {
+    ogs_assert(type);
     ogs_assert(pdr);
 
-    if (pdr->hashkey)
-        ogs_hash_set(ogs_pfcp_self()->pdr_hash,
-                &pdr->hashkey, sizeof(pdr->hashkey), NULL);
+    if (pdr->hash.teid.len)
+        ogs_hash_set(self.object_teid_hash,
+                &pdr->hash.teid.key, pdr->hash.teid.len, NULL);
 
-    pdr->hashkey = pdr_hash_keygen(pdr->f_teid.teid, pdr->qfi);
-    ogs_hash_set(ogs_pfcp_self()->pdr_hash,
-            &pdr->hashkey, sizeof(pdr->hashkey), pdr);
+    pdr->hash.teid.key = pdr->f_teid.teid;
+    pdr->hash.teid.len = sizeof(pdr->hash.teid.key);
+
+    switch(type) {
+    case OGS_PFCP_OBJ_PDR_TYPE:
+        ogs_hash_set(self.object_teid_hash,
+                &pdr->hash.teid.key, pdr->hash.teid.len, pdr);
+        break;
+    case OGS_PFCP_OBJ_SESS_TYPE:
+        ogs_assert(pdr->sess);
+        ogs_hash_set(self.object_teid_hash,
+                &pdr->hash.teid.key, pdr->hash.teid.len, pdr->sess);
+        break;
+    default:
+        ogs_fatal("Unknown type [%d]", type);
+        ogs_assert_if_reached();
+    }
 }
 
-ogs_pfcp_pdr_t *ogs_pfcp_pdr_find_by_teid_and_qfi(uint32_t teid, uint8_t qfi)
+ogs_pfcp_object_t *ogs_pfcp_object_find_by_teid(uint32_t teid)
 {
-    uint64_t hashkey = pdr_hash_keygen(teid, qfi);
-    return (ogs_pfcp_pdr_t *)ogs_hash_get(self.pdr_hash,
-            &hashkey, sizeof(hashkey));
+    return (ogs_pfcp_object_t *)ogs_hash_get(
+            self.object_teid_hash, &teid, sizeof(teid));
+}
+
+ogs_pfcp_pdr_t *ogs_pfcp_pdr_find_by_choose_id(
+        ogs_pfcp_sess_t *sess, uint8_t choose_id)
+{
+    ogs_pfcp_pdr_t *pdr = NULL;
+
+    ogs_assert(sess);
+
+    ogs_list_for_each(&sess->pdr_list, pdr)
+        if (pdr->chid == true && pdr->choose_id == choose_id)
+            return pdr;
+
+    return NULL;
 }
 
 void ogs_pfcp_pdr_reorder_by_precedence(
@@ -926,7 +953,7 @@ void ogs_pfcp_pdr_associate_far(ogs_pfcp_pdr_t *pdr, ogs_pfcp_far_t *far)
 {
     ogs_assert(pdr);
     ogs_assert(far);
-    
+
     pdr->far = far;
 }
 void ogs_pfcp_pdr_associate_urr(ogs_pfcp_pdr_t *pdr, ogs_pfcp_urr_t *urr)
@@ -953,9 +980,10 @@ void ogs_pfcp_pdr_remove(ogs_pfcp_pdr_t *pdr)
 
     ogs_pfcp_rule_remove_all(pdr);
 
-    if (pdr->hashkey)
-        ogs_hash_set(ogs_pfcp_self()->pdr_hash,
-                &pdr->hashkey, sizeof(pdr->hashkey), NULL);
+    if (pdr->hash.teid.len)
+        ogs_hash_set(self.object_teid_hash,
+                &pdr->hash.teid.key, pdr->hash.teid.len, NULL);
+
     if (pdr->dnn)
         ogs_free(pdr->dnn);
 
@@ -990,7 +1018,7 @@ ogs_pfcp_far_t *ogs_pfcp_far_add(ogs_pfcp_sess_t *sess)
     far->id = *(far->id_node);
     ogs_assert(far->id > 0 && far->id <= OGS_MAX_NUM_OF_FAR);
 
-    far->apply_action = OGS_PFCP_APPLY_ACTION_FORW;
+    far->dst_if = OGS_PFCP_INTERFACE_UNKNOWN;
 
     far->sess = sess;
     ogs_list_add(&sess->far_list, far);
@@ -1028,7 +1056,7 @@ ogs_pfcp_far_t *ogs_pfcp_far_find_or_add(
     return far;
 }
 
-void ogs_pfcp_far_hash_set(ogs_pfcp_far_t *far)
+void ogs_pfcp_far_f_teid_hash_set(ogs_pfcp_far_t *far)
 {
     int family;
 
@@ -1041,22 +1069,22 @@ void ogs_pfcp_far_hash_set(ogs_pfcp_far_t *far)
     addr = &gnode->addr;
     ogs_assert(addr);
 
-    if (far->hashkey_len)
-        ogs_hash_set(ogs_pfcp_self()->far_hash,
-                &far->hashkey, far->hashkey_len, NULL);
+    if (far->hash.f_teid.len)
+        ogs_hash_set(self.far_f_teid_hash,
+                &far->hash.f_teid.key, far->hash.f_teid.len, NULL);
 
-    far->hashkey.teid = far->outer_header_creation.teid;
-    far->hashkey_len = sizeof(far->hashkey.teid);
+    far->hash.f_teid.key.teid = far->outer_header_creation.teid;
+    far->hash.f_teid.len = sizeof(far->hash.f_teid.key.teid);
 
     family = addr->ogs_sa_family;
     switch (family) {
     case AF_INET:
-        memcpy(far->hashkey.addr, &addr->sin.sin_addr, OGS_IPV4_LEN);
-        far->hashkey_len += OGS_IPV4_LEN;
+        memcpy(far->hash.f_teid.key.addr, &addr->sin.sin_addr, OGS_IPV4_LEN);
+        far->hash.f_teid.len += OGS_IPV4_LEN;
         break;
     case AF_INET6:
-        memcpy(far->hashkey.addr, &addr->sin6.sin6_addr, OGS_IPV6_LEN);
-        far->hashkey_len += OGS_IPV6_LEN;
+        memcpy(far->hash.f_teid.key.addr, &addr->sin6.sin6_addr, OGS_IPV6_LEN);
+        far->hash.f_teid.len += OGS_IPV6_LEN;
         break;
     default:
         ogs_fatal("Unknown family(%d)", family);
@@ -1064,13 +1092,13 @@ void ogs_pfcp_far_hash_set(ogs_pfcp_far_t *far)
         return;
     }
 
-    ogs_hash_set(ogs_pfcp_self()->far_hash,
-            &far->hashkey, far->hashkey_len, far);
+    ogs_hash_set(self.far_f_teid_hash,
+            &far->hash.f_teid.key, far->hash.f_teid.len, far);
 }
 
 ogs_pfcp_far_t *ogs_pfcp_far_find_by_error_indication(ogs_pkbuf_t *pkbuf)
 {
-    ogs_pfcp_far_hashkey_t hashkey;
+    ogs_pfcp_far_hash_f_teid_t hashkey;
     int hashkey_len;
 
     uint32_t teid;
@@ -1126,7 +1154,29 @@ ogs_pfcp_far_t *ogs_pfcp_far_find_by_error_indication(ogs_pkbuf_t *pkbuf)
     memcpy(hashkey.addr, p, len);
     hashkey_len = 4 + len;
 
-    return (ogs_pfcp_far_t *)ogs_hash_get(self.far_hash, &hashkey, hashkey_len);
+    return (ogs_pfcp_far_t *)ogs_hash_get(
+            self.far_f_teid_hash, &hashkey, hashkey_len);
+}
+
+void ogs_pfcp_far_teid_hash_set(ogs_pfcp_far_t *far)
+{
+    ogs_assert(far);
+
+    if (far->hash.teid.len)
+        ogs_hash_set(self.far_teid_hash,
+                &far->hash.teid.key, far->hash.teid.len, NULL);
+
+    far->hash.teid.key = far->outer_header_creation.teid;
+    far->hash.teid.len = sizeof(far->hash.teid.key);
+
+    ogs_hash_set(self.far_teid_hash,
+            &far->hash.teid.key, far->hash.teid.len, far);
+}
+
+ogs_pfcp_far_t *ogs_pfcp_far_find_by_teid(uint32_t teid)
+{
+    return (ogs_pfcp_far_t *)ogs_hash_get(
+            self.far_teid_hash, &teid, sizeof(teid));
 }
 
 void ogs_pfcp_far_remove(ogs_pfcp_far_t *far)
@@ -1140,9 +1190,9 @@ void ogs_pfcp_far_remove(ogs_pfcp_far_t *far)
 
     ogs_list_remove(&sess->far_list, far);
 
-    if (far->hashkey_len)
-        ogs_hash_set(ogs_pfcp_self()->far_hash,
-                &far->hashkey, far->hashkey_len, NULL);
+    if (far->hash.f_teid.len)
+        ogs_hash_set(self.far_f_teid_hash,
+                &far->hash.f_teid.key, far->hash.f_teid.len, NULL);
 
     for (i = 0; i < far->num_of_buffered_packet; i++)
         ogs_pkbuf_free(far->buffered_packet[i]);
@@ -1333,6 +1383,9 @@ ogs_pfcp_bar_t *ogs_pfcp_bar_new(ogs_pfcp_sess_t *sess)
     ogs_pool_alloc(&sess->bar_id_pool, &bar->id_node);
     ogs_assert(bar->id_node);
 
+    bar->id = *(bar->id_node);
+    ogs_assert(bar->id > 0 && bar->id <= OGS_MAX_NUM_OF_BAR);
+
     bar->sess = sess;
     sess->bar = bar;
 
@@ -1347,13 +1400,13 @@ void ogs_pfcp_bar_delete(ogs_pfcp_bar_t *bar)
     sess = bar->sess;
     ogs_assert(sess);
 
-    bar->sess = NULL;
-    sess->bar = NULL;
-
     if (bar->id_node)
         ogs_pool_free(&bar->sess->bar_id_pool, bar->id_node);
 
     ogs_pool_free(&ogs_pfcp_bar_pool, bar);
+
+    bar->sess = NULL;
+    sess->bar = NULL;
 }
 
 ogs_pfcp_rule_t *ogs_pfcp_rule_add(ogs_pfcp_pdr_t *pdr)
@@ -1372,6 +1425,24 @@ ogs_pfcp_rule_t *ogs_pfcp_rule_add(ogs_pfcp_pdr_t *pdr)
     return rule;
 }
 
+ogs_pfcp_rule_t *ogs_pfcp_rule_find_by_sdf_filter_id(
+        ogs_pfcp_sess_t *sess, uint32_t sdf_filter_id)
+{
+    ogs_pfcp_pdr_t *pdr = NULL;
+    ogs_pfcp_rule_t *rule = NULL;
+
+    ogs_assert(sess);
+
+    ogs_list_for_each(&sess->pdr_list, pdr) {
+        ogs_list_for_each(&pdr->rule_list, rule) {
+            if (rule->bid && rule->sdf_filter_id == sdf_filter_id)
+                return rule;
+        }
+    }
+
+    return NULL;
+}
+
 void ogs_pfcp_rule_remove(ogs_pfcp_rule_t *rule)
 {
     ogs_pfcp_pdr_t *pdr = NULL;
@@ -1411,8 +1482,8 @@ int ogs_pfcp_ue_pool_generate(void)
             maxbytes = 4;
             lastindex = 0;
         } else if (subnet->family == AF_INET6) {
-            maxbytes = 16;
-            lastindex = 3;
+            maxbytes = 8; /* Default Prefixlen 64bits */
+            lastindex = 1;
         } else {
             /* subnet->family might be AF_UNSPEC. So, skip it */
             continue;
@@ -1431,8 +1502,7 @@ int ogs_pfcp_ue_pool_generate(void)
             if (subnet->num_of_range &&
                 subnet->range[rangeindex].low) {
                 ogs_ipsubnet_t low;
-                rv = ogs_ipsubnet(
-                        &low, subnet->range[rangeindex].low, NULL);
+                rv = ogs_ipsubnet(&low, subnet->range[rangeindex].low, NULL);
                 ogs_assert(rv == OGS_OK);
                 memcpy(start, low.sub, maxbytes);
             } else {
@@ -1442,8 +1512,7 @@ int ogs_pfcp_ue_pool_generate(void)
             if (subnet->num_of_range &&
                 subnet->range[rangeindex].high) {
                 ogs_ipsubnet_t high;
-                rv = ogs_ipsubnet(
-                        &high, subnet->range[rangeindex].high, NULL);
+                rv = ogs_ipsubnet(&high, subnet->range[rangeindex].high, NULL);
                 ogs_assert(rv == OGS_OK);
                 high.sub[lastindex] += htobe32(1);
                 memcpy(end, high.sub, maxbytes);
@@ -1475,6 +1544,10 @@ int ogs_pfcp_ue_pool_generate(void)
                 if (memcmp(ue_ip->addr, subnet->gw.sub, maxbytes) == 0)
                     continue;
 
+                /* Allocate Full IPv6 Address */
+                if (lastindex == 1)
+                    ue_ip->addr[3] += htobe32(inc);
+
                 ogs_trace("[%d] - %x:%x:%x:%x",
                         poolindex,
                         ue_ip->addr[0], ue_ip->addr[1],
@@ -1490,7 +1563,7 @@ int ogs_pfcp_ue_pool_generate(void)
 }
 
 ogs_pfcp_ue_ip_t *ogs_pfcp_ue_ip_alloc(
-        int family, const char *apn, uint8_t *addr)
+        int family, const char *dnn, uint8_t *addr)
 {
     ogs_pfcp_subnet_t *subnet = NULL;
     ogs_pfcp_ue_ip_t *ue_ip = NULL;
@@ -1498,22 +1571,6 @@ ogs_pfcp_ue_ip_t *ogs_pfcp_ue_ip_alloc(
     uint8_t zero[16];
     size_t maxbytes = 0;
 
-    ogs_assert(apn);
-    subnet = ogs_pfcp_find_subnet(family, apn);
-    if (subnet == NULL) {
-        ogs_error("CHECK CONFIGURATION: Cannot find subnet [family:%d, apn:%s]",
-                    family, apn);
-        ogs_error("smf");
-        ogs_error("    pdn:");
-        if (family == AF_INET)
-            ogs_error("     - addr: 10.45.0.1/16");
-        else if (family == AF_INET6)
-            ogs_error("     - addr: cafe::1/64");
-
-        ogs_assert_if_reached();
-        return NULL;
-    }
-
     memset(zero, 0, sizeof zero);
     if (family == AF_INET) {
         maxbytes = 4;
@@ -1524,7 +1581,26 @@ ogs_pfcp_ue_ip_t *ogs_pfcp_ue_ip_alloc(
         ogs_assert_if_reached();
     }
 
-    // if assigning a static IP, do so. If not, assign dynamically!
+    if (dnn)
+        subnet = ogs_pfcp_find_subnet_by_dnn(family, dnn);
+    else
+        subnet = ogs_pfcp_find_subnet(family);
+
+    if (subnet == NULL) {
+        ogs_error("CHECK CONFIGURATION: Cannot find subnet [family:%d, dnn:%s]",
+                    family, dnn ? dnn : "No DNN");
+        ogs_error("smf");
+        ogs_error("    subnet:");
+        if (family == AF_INET)
+            ogs_error("     - addr: 10.45.0.1/16");
+        else if (family == AF_INET6)
+            ogs_error("     - addr: 2001:230:cafe::1/48");
+
+        ogs_assert_if_reached();
+        return NULL;
+    }
+
+    /* if assigning a static IP, do so. If not, assign dynamically! */
     if (memcmp(addr, zero, maxbytes) != 0) {
         ue_ip = ogs_calloc(1, sizeof(ogs_pfcp_ue_ip_t));
 
@@ -1608,7 +1684,7 @@ ogs_pfcp_dev_t *ogs_pfcp_dev_find_by_ifname(const char *ifname)
 
 ogs_pfcp_subnet_t *ogs_pfcp_subnet_add(
         const char *ipstr, const char *mask_or_numbits,
-        const char *apn, const char *ifname)
+        const char *dnn, const char *ifname)
 {
     int rv;
     ogs_pfcp_dev_t *dev = NULL;
@@ -1639,8 +1715,8 @@ ogs_pfcp_subnet_t *ogs_pfcp_subnet_add(
         subnet->prefixlen = atoi(mask_or_numbits);
     }
 
-    if (apn)
-        strcpy(subnet->apn, apn);
+    if (dnn)
+        strcpy(subnet->dnn, dnn);
 
     ogs_pool_init(&subnet->pool, ogs_app()->pool.sess);
 
@@ -1668,17 +1744,32 @@ void ogs_pfcp_subnet_remove_all(void)
         ogs_pfcp_subnet_remove(subnet);
 }
 
-ogs_pfcp_subnet_t *ogs_pfcp_find_subnet(int family, const char *apn)
+ogs_pfcp_subnet_t *ogs_pfcp_find_subnet(int family)
 {
     ogs_pfcp_subnet_t *subnet = NULL;
 
-    ogs_assert(apn);
     ogs_assert(family == AF_INET || family == AF_INET6);
 
     ogs_list_for_each(&self.subnet_list, subnet) {
         if ((subnet->family == AF_UNSPEC || subnet->family == family) &&
-            (strlen(subnet->apn) == 0 ||
-                (strlen(subnet->apn) && ogs_strcasecmp(subnet->apn, apn) == 0)))
+            (strlen(subnet->dnn) == 0))
+            break;
+    }
+
+    return subnet;
+}
+
+ogs_pfcp_subnet_t *ogs_pfcp_find_subnet_by_dnn(int family, const char *dnn)
+{
+    ogs_pfcp_subnet_t *subnet = NULL;
+
+    ogs_assert(dnn);
+    ogs_assert(family == AF_INET || family == AF_INET6);
+
+    ogs_list_for_each(&self.subnet_list, subnet) {
+        if ((subnet->family == AF_UNSPEC || subnet->family == family) &&
+            (strlen(subnet->dnn) == 0 ||
+                (strlen(subnet->dnn) && ogs_strcasecmp(subnet->dnn, dnn) == 0)))
             break;
     }
 
@@ -1691,6 +1782,8 @@ void ogs_pfcp_pool_init(ogs_pfcp_sess_t *sess)
 
     ogs_assert(sess);
 
+    sess->obj.type = OGS_PFCP_OBJ_SESS_TYPE;
+
     ogs_index_init(&sess->pdr_id_pool, OGS_MAX_NUM_OF_PDR);
     ogs_index_init(&sess->far_id_pool, OGS_MAX_NUM_OF_FAR);
     ogs_index_init(&sess->urr_id_pool, OGS_MAX_NUM_OF_URR);
