@@ -96,10 +96,6 @@ cJSON *OpenAPI_amf3_gpp_access_registration_convertToJSON(OpenAPI_amf3_gpp_acces
     }
 
     item = cJSON_CreateObject();
-    if (!amf3_gpp_access_registration->amf_instance_id) {
-        ogs_error("OpenAPI_amf3_gpp_access_registration_convertToJSON() failed [amf_instance_id]");
-        goto end;
-    }
     if (cJSON_AddStringToObject(item, "amfInstanceId", amf3_gpp_access_registration->amf_instance_id) == NULL) {
         ogs_error("OpenAPI_amf3_gpp_access_registration_convertToJSON() failed [amf_instance_id]");
         goto end;
@@ -139,10 +135,6 @@ cJSON *OpenAPI_amf3_gpp_access_registration_convertToJSON(OpenAPI_amf3_gpp_acces
         }
     }
 
-    if (!amf3_gpp_access_registration->dereg_callback_uri) {
-        ogs_error("OpenAPI_amf3_gpp_access_registration_convertToJSON() failed [dereg_callback_uri]");
-        goto end;
-    }
     if (cJSON_AddStringToObject(item, "deregCallbackUri", amf3_gpp_access_registration->dereg_callback_uri) == NULL) {
         ogs_error("OpenAPI_amf3_gpp_access_registration_convertToJSON() failed [dereg_callback_uri]");
         goto end;
@@ -176,10 +168,6 @@ cJSON *OpenAPI_amf3_gpp_access_registration_convertToJSON(OpenAPI_amf3_gpp_acces
         }
     }
 
-    if (!amf3_gpp_access_registration->guami) {
-        ogs_error("OpenAPI_amf3_gpp_access_registration_convertToJSON() failed [guami]");
-        goto end;
-    }
     cJSON *guami_local_JSON = OpenAPI_guami_convertToJSON(amf3_gpp_access_registration->guami);
     if (guami_local_JSON == NULL) {
         ogs_error("OpenAPI_amf3_gpp_access_registration_convertToJSON() failed [guami]");
@@ -218,10 +206,6 @@ cJSON *OpenAPI_amf3_gpp_access_registration_convertToJSON(OpenAPI_amf3_gpp_acces
         }
     }
 
-    if (!amf3_gpp_access_registration->rat_type) {
-        ogs_error("OpenAPI_amf3_gpp_access_registration_convertToJSON() failed [rat_type]");
-        goto end;
-    }
     if (cJSON_AddStringToObject(item, "ratType", OpenAPI_rat_type_ToString(amf3_gpp_access_registration->rat_type)) == NULL) {
         ogs_error("OpenAPI_amf3_gpp_access_registration_convertToJSON() failed [rat_type]");
         goto end;
