@@ -58,10 +58,6 @@ cJSON *OpenAPI_dnn_upf_info_item_convertToJSON(OpenAPI_dnn_upf_info_item_t *dnn_
     }
 
     item = cJSON_CreateObject();
-    if (!dnn_upf_info_item->dnn) {
-        ogs_error("OpenAPI_dnn_upf_info_item_convertToJSON() failed [dnn]");
-        goto end;
-    }
     if (cJSON_AddStringToObject(item, "dnn", dnn_upf_info_item->dnn) == NULL) {
         ogs_error("OpenAPI_dnn_upf_info_item_convertToJSON() failed [dnn]");
         goto end;
@@ -91,7 +87,7 @@ cJSON *OpenAPI_dnn_upf_info_item_convertToJSON(OpenAPI_dnn_upf_info_item_t *dnn_
         }
         OpenAPI_lnode_t *pdu_session_types_node;
         OpenAPI_list_for_each(dnn_upf_info_item->pdu_session_types, pdu_session_types_node) {
-            if (cJSON_AddStringToObject(pdu_session_types, "", OpenAPI_pdu_session_type_ToString((OpenAPI_pdu_session_type_e)pdu_session_types_node->data)) == NULL) {
+            if (cJSON_AddStringToObject(pdu_session_types, "", OpenAPI_pdu_session_type_ToString((intptr_t)pdu_session_types_node->data)) == NULL) {
                 ogs_error("OpenAPI_dnn_upf_info_item_convertToJSON() failed [pdu_session_types]");
                 goto end;
             }
