@@ -7,7 +7,8 @@
 OpenAPI_emergency_info_t *OpenAPI_emergency_info_create(
     char *pgw_fqdn,
     OpenAPI_ip_address_t *pgw_ip_address,
-    char *smf_instance_id
+    char *smf_instance_id,
+    int epdg_ind
     )
 {
     OpenAPI_emergency_info_t *emergency_info_local_var = OpenAPI_malloc(sizeof(OpenAPI_emergency_info_t));
@@ -17,6 +18,7 @@ OpenAPI_emergency_info_t *OpenAPI_emergency_info_create(
     emergency_info_local_var->pgw_fqdn = pgw_fqdn;
     emergency_info_local_var->pgw_ip_address = pgw_ip_address;
     emergency_info_local_var->smf_instance_id = smf_instance_id;
+    emergency_info_local_var->epdg_ind = epdg_ind;
 
     return emergency_info_local_var;
 }
@@ -70,6 +72,13 @@ cJSON *OpenAPI_emergency_info_convertToJSON(OpenAPI_emergency_info_t *emergency_
         }
     }
 
+    if (emergency_info->epdg_ind) {
+        if (cJSON_AddBoolToObject(item, "epdgInd", emergency_info->epdg_ind) == NULL) {
+            ogs_error("OpenAPI_emergency_info_convertToJSON() failed [epdg_ind]");
+            goto end;
+        }
+    }
+
 end:
     return item;
 }
@@ -102,10 +111,20 @@ OpenAPI_emergency_info_t *OpenAPI_emergency_info_parseFromJSON(cJSON *emergency_
         }
     }
 
+    cJSON *epdg_ind = cJSON_GetObjectItemCaseSensitive(emergency_infoJSON, "epdgInd");
+
+    if (epdg_ind) {
+        if (!cJSON_IsBool(epdg_ind)) {
+            ogs_error("OpenAPI_emergency_info_parseFromJSON() failed [epdg_ind]");
+            goto end;
+        }
+    }
+
     emergency_info_local_var = OpenAPI_emergency_info_create (
         pgw_fqdn ? ogs_strdup(pgw_fqdn->valuestring) : NULL,
         pgw_ip_address ? pgw_ip_address_local_nonprim : NULL,
-        smf_instance_id ? ogs_strdup(smf_instance_id->valuestring) : NULL
+        smf_instance_id ? ogs_strdup(smf_instance_id->valuestring) : NULL,
+        epdg_ind ? epdg_ind->valueint : 0
         );
 
     return emergency_info_local_var;
