@@ -54,19 +54,11 @@ cJSON *OpenAPI_model_5_g_vn_group_data_convertToJSON(OpenAPI_model_5_g_vn_group_
     }
 
     item = cJSON_CreateObject();
-    if (!model_5_g_vn_group_data->dnn) {
-        ogs_error("OpenAPI_model_5_g_vn_group_data_convertToJSON() failed [dnn]");
-        goto end;
-    }
     if (cJSON_AddStringToObject(item, "dnn", model_5_g_vn_group_data->dnn) == NULL) {
         ogs_error("OpenAPI_model_5_g_vn_group_data_convertToJSON() failed [dnn]");
         goto end;
     }
 
-    if (!model_5_g_vn_group_data->s_nssai) {
-        ogs_error("OpenAPI_model_5_g_vn_group_data_convertToJSON() failed [s_nssai]");
-        goto end;
-    }
     cJSON *s_nssai_local_JSON = OpenAPI_snssai_convertToJSON(model_5_g_vn_group_data->s_nssai);
     if (s_nssai_local_JSON == NULL) {
         ogs_error("OpenAPI_model_5_g_vn_group_data_convertToJSON() failed [s_nssai]");
@@ -86,7 +78,7 @@ cJSON *OpenAPI_model_5_g_vn_group_data_convertToJSON(OpenAPI_model_5_g_vn_group_
         }
         OpenAPI_lnode_t *pdu_session_types_node;
         OpenAPI_list_for_each(model_5_g_vn_group_data->pdu_session_types, pdu_session_types_node) {
-            if (cJSON_AddStringToObject(pdu_session_types, "", OpenAPI_pdu_session_type_ToString((OpenAPI_pdu_session_type_e)pdu_session_types_node->data)) == NULL) {
+            if (cJSON_AddStringToObject(pdu_session_types, "", OpenAPI_pdu_session_type_ToString((intptr_t)pdu_session_types_node->data)) == NULL) {
                 ogs_error("OpenAPI_model_5_g_vn_group_data_convertToJSON() failed [pdu_session_types]");
                 goto end;
             }
