@@ -23,13 +23,17 @@ typedef struct OpenAPI_non_dynamic5_qi_s {
     int aver_window;
     int max_data_burst_vol;
     int ext_max_data_burst_vol;
+    int cn_packet_delay_budget_dl;
+    int cn_packet_delay_budget_ul;
 } OpenAPI_non_dynamic5_qi_t;
 
 OpenAPI_non_dynamic5_qi_t *OpenAPI_non_dynamic5_qi_create(
     int priority_level,
     int aver_window,
     int max_data_burst_vol,
-    int ext_max_data_burst_vol
+    int ext_max_data_burst_vol,
+    int cn_packet_delay_budget_dl,
+    int cn_packet_delay_budget_ul
     );
 void OpenAPI_non_dynamic5_qi_free(OpenAPI_non_dynamic5_qi_t *non_dynamic5_qi);
 OpenAPI_non_dynamic5_qi_t *OpenAPI_non_dynamic5_qi_parseFromJSON(cJSON *non_dynamic5_qiJSON);
