@@ -6,7 +6,7 @@
 
 char* OpenAPI_rat_type_ToString(OpenAPI_rat_type_e rat_type)
 {
-    const char *rat_typeArray[] =  { "NULL", "NR", "EUTRA", "WLAN", "VIRTUAL", "NBIOT", "WIRELINE", "WIRELINE_CABLE", "WIRELINE_DSL", "WIRELINE_PON", "LTE_M", "NR_U", "EUTRA_U", "TRUSTED_N3GA", "TRUSTED_WLAN", "UTRA", "GERA" };
+    const char *rat_typeArray[] =  { "NULL", "NR", "EUTRA", "WLAN", "VIRTUAL", "NBIOT", "WIRELINE", "WIRELINE_CABLE", "WIRELINE_BBF", "LTE_M", "NR_U", "EUTRA_U", "TRUSTED_N3GA", "TRUSTED_WLAN", "UTRA", "GERA" };
     size_t sizeofArray = sizeof(rat_typeArray) / sizeof(rat_typeArray[0]);
     if (rat_type < sizeofArray)
         return (char *)rat_typeArray[rat_type];
@@ -17,7 +17,7 @@ char* OpenAPI_rat_type_ToString(OpenAPI_rat_type_e rat_type)
 OpenAPI_rat_type_e OpenAPI_rat_type_FromString(char* rat_type)
 {
     int stringToReturn = 0;
-    const char *rat_typeArray[] =  { "NULL", "NR", "EUTRA", "WLAN", "VIRTUAL", "NBIOT", "WIRELINE", "WIRELINE_CABLE", "WIRELINE_DSL", "WIRELINE_PON", "LTE_M", "NR_U", "EUTRA_U", "TRUSTED_N3GA", "TRUSTED_WLAN", "UTRA", "GERA" };
+    const char *rat_typeArray[] =  { "NULL", "NR", "EUTRA", "WLAN", "VIRTUAL", "NBIOT", "WIRELINE", "WIRELINE_CABLE", "WIRELINE_BBF", "LTE_M", "NR_U", "EUTRA_U", "TRUSTED_N3GA", "TRUSTED_WLAN", "UTRA", "GERA" };
     size_t sizeofArray = sizeof(rat_typeArray) / sizeof(rat_typeArray[0]);
     while (stringToReturn < sizeofArray) {
         if (strcmp(rat_type, rat_typeArray[stringToReturn]) == 0) {
