@@ -62,10 +62,6 @@ cJSON *OpenAPI_smf_info_convertToJSON(OpenAPI_smf_info_t *smf_info)
     }
 
     item = cJSON_CreateObject();
-    if (!smf_info->s_nssai_smf_info_list) {
-        ogs_error("OpenAPI_smf_info_convertToJSON() failed [s_nssai_smf_info_list]");
-        goto end;
-    }
     cJSON *s_nssai_smf_info_listList = cJSON_AddArrayToObject(item, "sNssaiSmfInfoList");
     if (s_nssai_smf_info_listList == NULL) {
         ogs_error("OpenAPI_smf_info_convertToJSON() failed [s_nssai_smf_info_list]");
@@ -139,7 +135,7 @@ cJSON *OpenAPI_smf_info_convertToJSON(OpenAPI_smf_info_t *smf_info)
         }
         OpenAPI_lnode_t *access_type_node;
         OpenAPI_list_for_each(smf_info->access_type, access_type_node) {
-            if (cJSON_AddStringToObject(access_type, "", OpenAPI_access_type_ToString((OpenAPI_access_type_e)access_type_node->data)) == NULL) {
+            if (cJSON_AddStringToObject(access_type, "", OpenAPI_access_type_ToString((intptr_t)access_type_node->data)) == NULL) {
                 ogs_error("OpenAPI_smf_info_convertToJSON() failed [access_type]");
                 goto end;
             }
