@@ -29,6 +29,7 @@ typedef struct OpenAPI_smf_info_s {
     char *pgw_fqdn;
     OpenAPI_list_t *access_type;
     int priority;
+    int vsmf_support_ind;
 } OpenAPI_smf_info_t;
 
 OpenAPI_smf_info_t *OpenAPI_smf_info_create(
@@ -37,7 +38,8 @@ OpenAPI_smf_info_t *OpenAPI_smf_info_create(
     OpenAPI_list_t *tai_range_list,
     char *pgw_fqdn,
     OpenAPI_list_t *access_type,
-    int priority
+    int priority,
+    int vsmf_support_ind
     );
 void OpenAPI_smf_info_free(OpenAPI_smf_info_t *smf_info);
 OpenAPI_smf_info_t *OpenAPI_smf_info_parseFromJSON(cJSON *smf_infoJSON);
