@@ -85,10 +85,6 @@ cJSON *OpenAPI_upf_info_convertToJSON(OpenAPI_upf_info_t *upf_info)
     }
 
     item = cJSON_CreateObject();
-    if (!upf_info->s_nssai_upf_info_list) {
-        ogs_error("OpenAPI_upf_info_convertToJSON() failed [s_nssai_upf_info_list]");
-        goto end;
-    }
     cJSON *s_nssai_upf_info_listList = cJSON_AddArrayToObject(item, "sNssaiUpfInfoList");
     if (s_nssai_upf_info_listList == NULL) {
         ogs_error("OpenAPI_upf_info_convertToJSON() failed [s_nssai_upf_info_list]");
@@ -158,7 +154,7 @@ cJSON *OpenAPI_upf_info_convertToJSON(OpenAPI_upf_info_t *upf_info)
         }
         OpenAPI_lnode_t *pdu_session_types_node;
         OpenAPI_list_for_each(upf_info->pdu_session_types, pdu_session_types_node) {
-            if (cJSON_AddStringToObject(pdu_session_types, "", OpenAPI_pdu_session_type_ToString((OpenAPI_pdu_session_type_e)pdu_session_types_node->data)) == NULL) {
+            if (cJSON_AddStringToObject(pdu_session_types, "", OpenAPI_pdu_session_type_ToString((intptr_t)pdu_session_types_node->data)) == NULL) {
                 ogs_error("OpenAPI_upf_info_convertToJSON() failed [pdu_session_types]");
                 goto end;
             }
