@@ -49,7 +49,7 @@ typedef struct ogs_sbi_server_actions_s {
     void (*init)(int num_of_session_pool, int num_of_stream_pool);
     void (*cleanup)(void);
 
-    void (*start)(ogs_sbi_server_t *server,
+    int (*start)(ogs_sbi_server_t *server,
             int (*cb)(ogs_sbi_request_t *request, void *data));
     void (*stop)(ogs_sbi_server_t *server);
 
@@ -69,7 +69,7 @@ void ogs_sbi_server_remove_all(void);
 void ogs_sbi_server_set_advertise(
         ogs_sbi_server_t *server, int family, ogs_sockaddr_t *advertise);
 
-void ogs_sbi_server_start_all(
+int ogs_sbi_server_start_all(
         int (*cb)(ogs_sbi_request_t *request, void *data));
 void ogs_sbi_server_stop_all(void);
 
