@@ -1025,7 +1025,6 @@ ran_ue_t *ran_ue_find_by_ran_ue_ngap_id(
 
 ran_ue_t *ran_ue_find(uint32_t index)
 {
-    ogs_assert(index);
     return ogs_pool_find(&ran_ue_pool, index);
 }
 
@@ -1106,9 +1105,10 @@ amf_ue_t *amf_ue_add(ran_ue_t *ran_ue)
 
     ogs_list_init(&amf_ue->sess_list);
 
-    /* TODO : Hard-coded */
+    /* Initialization */
     amf_ue->guami = &amf_self()->served_guami[0];
     amf_ue->nas.access_type = OGS_ACCESS_TYPE_3GPP;
+    amf_ue->nas.amf.ksi = OGS_NAS_KSI_NO_KEY_IS_AVAILABLE;
     amf_ue->abba_len = 2;
 
     /* Add All Timers */
@@ -1290,6 +1290,7 @@ amf_ue_t *amf_ue_find_by_message(ogs_nas_5gs_message_t *message)
     ogs_nas_5gs_service_request_t *service_request = NULL;
     ogs_nas_5gs_mobile_identity_t *mobile_identity = NULL;
     ogs_nas_5gs_mobile_identity_header_t *mobile_identity_header = NULL;
+    ogs_nas_5gs_mobile_identity_suci_t *mobile_identity_suci = NULL;
     ogs_nas_5gs_mobile_identity_guti_t *mobile_identity_guti = NULL;
     ogs_nas_5gs_mobile_identity_s_tmsi_t *mobile_identity_s_tmsi = NULL;
     ogs_nas_5gs_guti_t nas_guti;
@@ -1316,6 +1317,15 @@ amf_ue_t *amf_ue_find_by_message(ogs_nas_5gs_message_t *message)
 
         switch (mobile_identity_header->type) {
         case OGS_NAS_5GS_MOBILE_IDENTITY_SUCI:
+            mobile_identity_suci =
+                (ogs_nas_5gs_mobile_identity_suci_t *)mobile_identity->buffer;
+            if (mobile_identity_suci->protection_scheme_id !=
+                    OGS_NAS_5GS_NULL_SCHEME) {
+                ogs_error("Not implemented ProtectionSchemeID(%d) in SUCI",
+                    mobile_identity_suci->protection_scheme_id);
+                return NULL;
+            }
+
             suci = ogs_nas_5gs_suci_from_mobile_identity(mobile_identity);
             ogs_assert(suci);
 
@@ -1755,6 +1765,19 @@ bool amf_pdu_res_setup_req_transfer_needed(amf_ue_t *amf_ue)
     return false;
 }
 
+bool amf_handover_request_transfer_needed(amf_ue_t *amf_ue)
+{
+    amf_sess_t *sess = NULL;
+
+    ogs_assert(amf_ue);
+
+    ogs_list_for_each(&amf_ue->sess_list, sess)
+        if (sess->transfer.handover_request)
+            return true;
+
+    return false;
+}
+
 int amf_find_served_tai(ogs_5gs_tai_t *nr_tai)
 {
     int i = 0, j = 0, k = 0;
