@@ -42,30 +42,34 @@ int amf_nnssf_nsselection_handle_get(
     if (recvmsg->res_status != OGS_SBI_HTTP_STATUS_OK) {
         ogs_error("[%s] HTTP response error [%d]",
                 amf_ue->supi, recvmsg->res_status);
-        nas_5gs_send_gmm_status(amf_ue, recvmsg->res_status);
+        ogs_assert(OGS_OK ==
+            nas_5gs_send_gmm_status(amf_ue, recvmsg->res_status));
         return OGS_ERROR;
     }
 
     AuthorizedNetworkSliceInfo = recvmsg->AuthorizedNetworkSliceInfo;
     if (!AuthorizedNetworkSliceInfo) {
         ogs_error("No AuthorizedNetworkSliceInfo");
-        nas_5gs_send_gmm_reject_from_sbi(
-                amf_ue, OGS_SBI_HTTP_STATUS_INTERNAL_SERVER_ERROR);
+        ogs_assert(OGS_OK ==
+            nas_5gs_send_gmm_reject_from_sbi(
+                amf_ue, OGS_SBI_HTTP_STATUS_INTERNAL_SERVER_ERROR));
         return OGS_ERROR;
     }
 
     NsiInformation = AuthorizedNetworkSliceInfo->nsi_information;
     if (!NsiInformation) {
         ogs_error("No NsiInformation");
-        nas_5gs_send_gmm_reject_from_sbi(
-                amf_ue, OGS_SBI_HTTP_STATUS_INTERNAL_SERVER_ERROR);
+        ogs_assert(OGS_OK ==
+            nas_5gs_send_gmm_reject_from_sbi(
+                amf_ue, OGS_SBI_HTTP_STATUS_INTERNAL_SERVER_ERROR));
         return OGS_ERROR;
     }
 
     if (!NsiInformation->nrf_id) {
         ogs_error("No nrfId");
-        nas_5gs_send_gmm_reject_from_sbi(
-                amf_ue, OGS_SBI_HTTP_STATUS_INTERNAL_SERVER_ERROR);
+        ogs_assert(OGS_OK ==
+            nas_5gs_send_gmm_reject_from_sbi(
+                amf_ue, OGS_SBI_HTTP_STATUS_INTERNAL_SERVER_ERROR));
         return OGS_ERROR;
     }
 
@@ -77,8 +81,9 @@ int amf_nnssf_nsselection_handle_get(
     if (!addr) {
         ogs_error("[%s:%d] Invalid URI [%s]",
                 amf_ue->supi, sess->psi, NsiInformation->nrf_id);
-        nas_5gs_send_gmm_reject_from_sbi(
-                amf_ue, OGS_SBI_HTTP_STATUS_INTERNAL_SERVER_ERROR);
+        ogs_assert(OGS_OK ==
+            nas_5gs_send_gmm_reject_from_sbi(
+                amf_ue, OGS_SBI_HTTP_STATUS_INTERNAL_SERVER_ERROR));
         return OGS_ERROR;;
     }
 
