@@ -23,6 +23,9 @@
 #include "nausf-build.h"
 #include "nudm-build.h"
 #include "nsmf-build.h"
+#include "npcf-build.h"
+#include "nnssf-build.h"
+#include "nnrf-build.h"
 
 #ifdef __cplusplus
 extern "C" {
@@ -31,24 +34,42 @@ extern "C" {
 int amf_sbi_open(void);
 void amf_sbi_close(void);
 
+void amf_nnrf_nfm_send_nf_register(ogs_sbi_nf_instance_t *nf_instance);
+
 void amf_sbi_send(ogs_sbi_nf_instance_t *nf_instance, ogs_sbi_xact_t *xact);
 void amf_ue_sbi_discover_and_send(OpenAPI_nf_type_e target_nf_type,
         amf_ue_t *amf_ue, void *data,
         ogs_sbi_request_t *(*build)(amf_ue_t *amf_ue, void *data));
 
-#define AMF_UPDATE_SM_CONTEXT_NO_STATE          0
-#define AMF_UPDATE_SM_CONTEXT_ACTIVATED         1
-#define AMF_UPDATE_SM_CONTEXT_DEACTIVATED       2
-#define AMF_UPDATE_SM_CONTEXT_ACTIVATING        3
-#define AMF_UPDATE_SM_CONTEXT_SUSPENDED         4
-#define AMF_UPDATE_SM_CONTEXT_N2_RELEASED       5
-#define AMF_UPDATE_SM_CONTEXT_N1_RELEASED       6
-#define AMF_UPDATE_SM_CONTEXT_NG_RESET          7
+#define AMF_CREATE_SM_CONTEXT_NO_STATE              0
+#define AMF_UPDATE_SM_CONTEXT_ACTIVATED             11
+#define AMF_UPDATE_SM_CONTEXT_DEACTIVATED           12
+#define AMF_UPDATE_SM_CONTEXT_REGISTRATION_REQUEST  13
+#define AMF_UPDATE_SM_CONTEXT_SERVICE_REQUEST       14
+#define AMF_UPDATE_SM_CONTEXT_MODIFIED              15
+#define AMF_UPDATE_SM_CONTEXT_N2_RELEASED           16
+#define AMF_UPDATE_SM_CONTEXT_N1_RELEASED           17
+#define AMF_UPDATE_SM_CONTEXT_DUPLICATED_PDU_SESSION_ID 18
+#define AMF_UPDATE_SM_CONTEXT_PATH_SWITCH_REQUEST   19
+#define AMF_UPDATE_SM_CONTEXT_HANDOVER_REQUIRED     20
+#define AMF_UPDATE_SM_CONTEXT_HANDOVER_REQ_ACK      21
+#define AMF_UPDATE_SM_CONTEXT_HANDOVER_NOTIFY       22
+#define AMF_UPDATE_SM_CONTEXT_HANDOVER_CANCEL       23
+#define AMF_RELEASE_SM_CONTEXT_NO_STATE             31
+#define AMF_RELEASE_SM_CONTEXT_NG_CONTEXT_REMOVE    32
+#define AMF_RELEASE_SM_CONTEXT_REGISTRATION_ACCEPT  33
+#define AMF_RELEASE_SM_CONTEXT_SERVICE_ACCEPT       34
+#define AMF_REMOVE_S1_CONTEXT_BY_LO_CONNREFUSED     51
+#define AMF_REMOVE_S1_CONTEXT_BY_RESET_ALL          52
+#define AMF_REMOVE_S1_CONTEXT_BY_RESET_PARTIAL      53
 void amf_sess_sbi_discover_and_send(OpenAPI_nf_type_e target_nf_type,
         amf_sess_t *sess, int state, void *data,
         ogs_sbi_request_t *(*build)(amf_sess_t *sess, void *data));
 
-void amf_sbi_send_activating_session(amf_sess_t *sess);
+void amf_sess_sbi_discover_by_nsi(
+        OpenAPI_nf_type_e target_nf_type, amf_sess_t *sess);
+
+void amf_sbi_send_activating_session(amf_sess_t *sess, int state);
 
 void amf_sbi_send_deactivate_session(
         amf_sess_t *sess, int state, int group, int cause);
@@ -56,13 +77,12 @@ void amf_sbi_send_deactivate_all_sessions(
         amf_ue_t *amf_ue, int state, int group, int cause);
 void amf_sbi_send_deactivate_all_ue_in_gnb(amf_gnb_t *gnb, int state);
 
-#define AMF_RELEASE_SM_CONTEXT_NO_STATE             0
-#define AMF_RELEASE_SM_CONTEXT_NG_CONTEXT_REMOVE    1
-#define AMF_RELEASE_SM_CONTEXT_REGISTRATION_ACCEPT  2
-#define AMF_RELEASE_SM_CONTEXT_SERVICE_ACCEPT       3
 void amf_sbi_send_release_session(amf_sess_t *sess, int state);
 void amf_sbi_send_release_all_sessions(amf_ue_t *amf_ue, int state);
 
+void amf_sbi_send_n1_n2_failure_notify(
+        amf_sess_t *sess, OpenAPI_n1_n2_message_transfer_cause_e cause);
+
 #ifdef __cplusplus
 }
 #endif
