@@ -55,15 +55,9 @@ void ausf_state_operational(ogs_fsm_t *s, ausf_event_t *e)
 
     switch (e->id) {
     case OGS_FSM_ENTRY_SIG:
-        rv = ausf_sbi_open();
-        if (rv != OGS_OK) {
-            ogs_fatal("Can't establish SBI path");
-        }
-
         break;
 
     case OGS_FSM_EXIT_SIG:
-        ausf_sbi_close();
         break;
 
     case AUSF_EVT_SBI_SERVER:
@@ -279,15 +273,17 @@ void ausf_state_operational(ogs_fsm_t *s, ausf_event_t *e)
 
             ausf_ue = (ausf_ue_t *)sbi_xact->sbi_object;
             ogs_assert(ausf_ue);
+
+            e->sbi.data = sbi_xact->assoc_stream;
+
+            ogs_sbi_xact_remove(sbi_xact);
+
             ausf_ue = ausf_ue_cycle(ausf_ue);
             ogs_assert(ausf_ue);
             ogs_assert(OGS_FSM_STATE(&ausf_ue->sm));
 
             e->ausf_ue = ausf_ue;
             e->sbi.message = &message;
-            e->sbi.data = sbi_xact->assoc_stream;
-
-            ogs_sbi_xact_remove(sbi_xact);
 
             ogs_fsm_dispatch(&ausf_ue->sm, e);
             if (OGS_FSM_CHECK(&ausf_ue->sm, ausf_ue_state_exception)) {
