@@ -110,9 +110,10 @@ int emm_handle_attach_request(mme_ue_t *mme_ue,
         /* Send Attach Reject */
         ogs_warn("Cannot find Served TAI[PLMN_ID:%06x,TAC:%d]",
             ogs_plmn_id_hexdump(&mme_ue->tai.plmn_id), mme_ue->tai.tac);
-        nas_eps_send_attach_reject(mme_ue,
-            EMM_CAUSE_TRACKING_AREA_NOT_ALLOWED,
-            ESM_CAUSE_PROTOCOL_ERROR_UNSPECIFIED);
+        ogs_assert(OGS_OK ==
+            nas_eps_send_attach_reject(mme_ue,
+                EMM_CAUSE_TRACKING_AREA_NOT_ALLOWED,
+                ESM_CAUSE_PROTOCOL_ERROR_UNSPECIFIED));
         return OGS_ERROR;
     }
     ogs_debug("    SERVED_TAI_INDEX[%d]", served_tai_index);
@@ -152,9 +153,10 @@ int emm_handle_attach_request(mme_ue_t *mme_ue,
             "but Integrity[0x%x] cannot be bypassed with EIA0",
             mme_selected_enc_algorithm(mme_ue), 
             mme_selected_int_algorithm(mme_ue));
-        nas_eps_send_attach_reject(mme_ue,
-            EMM_CAUSE_UE_SECURITY_CAPABILITIES_MISMATCH,
-            ESM_CAUSE_PROTOCOL_ERROR_UNSPECIFIED);
+        ogs_assert(OGS_OK ==
+            nas_eps_send_attach_reject(mme_ue,
+                EMM_CAUSE_UE_SECURITY_CAPABILITIES_MISMATCH,
+                ESM_CAUSE_PROTOCOL_ERROR_UNSPECIFIED));
         return OGS_ERROR;
     }
 
@@ -501,7 +503,9 @@ int emm_handle_tau_request(mme_ue_t *mme_ue,
         /* Send TAU reject */
         ogs_warn("Cannot find Served TAI[PLMN_ID:%06x,TAC:%d]",
             ogs_plmn_id_hexdump(&mme_ue->tai.plmn_id), mme_ue->tai.tac);
-        nas_eps_send_tau_reject(mme_ue, EMM_CAUSE_TRACKING_AREA_NOT_ALLOWED);
+        ogs_assert(OGS_OK ==
+            nas_eps_send_tau_reject(
+                mme_ue, EMM_CAUSE_TRACKING_AREA_NOT_ALLOWED));
         return OGS_ERROR;
     }
     ogs_debug("    SERVED_TAI_INDEX[%d]", served_tai_index);
@@ -617,7 +621,9 @@ int emm_handle_extended_service_request(mme_ue_t *mme_ue,
         /* Send TAU reject */
         ogs_warn("Cannot find Served TAI[PLMN_ID:%06x,TAC:%d]",
             ogs_plmn_id_hexdump(&mme_ue->tai.plmn_id), mme_ue->tai.tac);
-        nas_eps_send_tau_reject(mme_ue, EMM_CAUSE_TRACKING_AREA_NOT_ALLOWED);
+        ogs_assert(OGS_OK ==
+            nas_eps_send_tau_reject(
+                mme_ue, EMM_CAUSE_TRACKING_AREA_NOT_ALLOWED));
         return OGS_ERROR;
     }
     ogs_debug("    SERVED_TAI_INDEX[%d]", served_tai_index);
