@@ -112,13 +112,14 @@ ogs_pkbuf_t *esm_build_activate_default_bearer_context_request(
     
     mme_ue_t *mme_ue = NULL;
     mme_bearer_t *bearer = NULL;
-    ogs_pdn_t *pdn = NULL;
+    ogs_session_t *session = NULL;
 
     ogs_assert(sess);
     mme_ue = sess->mme_ue;
     ogs_assert(mme_ue);
-    pdn = sess->pdn;
-    ogs_assert(pdn);
+    session = sess->session;
+    ogs_assert(session);
+    ogs_assert(session->name);
     bearer = mme_default_bearer_in_sess(sess);
     ogs_assert(bearer);
     ogs_assert(mme_bearer_next(bearer) == NULL);
@@ -139,16 +140,16 @@ ogs_pkbuf_t *esm_build_activate_default_bearer_context_request(
     message.esm.h.message_type =
         OGS_NAS_EPS_ACTIVATE_DEFAULT_EPS_BEARER_CONTEXT_REQUEST;
 
-    memcpy(&bearer->qos, &pdn->qos, sizeof(ogs_qos_t));
+    memcpy(&bearer->qos, &session->qos, sizeof(ogs_qos_t));
 
-    eps_qos_build(eps_qos, bearer->qos.qci,
+    eps_qos_build(eps_qos, bearer->qos.index,
             bearer->qos.mbr.downlink, bearer->qos.mbr.uplink,
             bearer->qos.gbr.downlink, bearer->qos.gbr.uplink);
 
-    access_point_name->length = strlen(pdn->apn);
-    ogs_cpystrn(access_point_name->apn, pdn->apn,
+    access_point_name->length = strlen(session->name);
+    ogs_cpystrn(access_point_name->apn, session->name,
             ogs_min(access_point_name->length, OGS_MAX_APN_LEN) + 1);
-    ogs_debug("    APN[%s]", pdn->apn);
+    ogs_debug("    APN[%s]", session->name);
 
     /*
      * In TS24.301 V15.6.0
@@ -164,32 +165,32 @@ ogs_pkbuf_t *esm_build_activate_default_bearer_context_request(
      * included in the ACTIVATE DEFAULT EPS BEARER CONTEXT REQUEST message.
      */
 
-    pdn_address->pdn_type = pdn->paa.pdn_type;
+    pdn_address->pdn_type = session->paa.session_type;
     if (sess->request_type.type == OGS_NAS_EPS_PDN_TYPE_IPV4V6) {
-        if (pdn->paa.pdn_type == OGS_GTP_PDN_TYPE_IPV4) {
-            pdn_address->pdn_type = OGS_GTP_PDN_TYPE_IPV4;
+        if (session->paa.session_type == OGS_PDU_SESSION_TYPE_IPV4) {
+            pdn_address->pdn_type = OGS_PDU_SESSION_TYPE_IPV4;
             activate_default_eps_bearer_context_request->esm_cause =
                 ESM_CAUSE_PDN_TYPE_IPV4_ONLY_ALLOWED;
             activate_default_eps_bearer_context_request->presencemask |=
                 OGS_NAS_EPS_ACTIVATE_DEFAULT_EPS_BEARER_CONTEXT_REQUEST_ESM_CAUSE_PRESENT;
-        } else if (pdn->paa.pdn_type == OGS_GTP_PDN_TYPE_IPV6) {
-            pdn_address->pdn_type = OGS_GTP_PDN_TYPE_IPV6;
+        } else if (session->paa.session_type == OGS_PDU_SESSION_TYPE_IPV6) {
+            pdn_address->pdn_type = OGS_PDU_SESSION_TYPE_IPV6;
             activate_default_eps_bearer_context_request->esm_cause =
                 ESM_CAUSE_PDN_TYPE_IPV6_ONLY_ALLOWED;
             activate_default_eps_bearer_context_request->presencemask |=
                 OGS_NAS_EPS_ACTIVATE_DEFAULT_EPS_BEARER_CONTEXT_REQUEST_ESM_CAUSE_PRESENT;
         }
-    } else if (sess->request_type.type == OGS_GTP_PDN_TYPE_IPV4) {
-        if (pdn->paa.pdn_type == OGS_GTP_PDN_TYPE_IPV6) {
-            pdn_address->pdn_type = OGS_GTP_PDN_TYPE_IPV6;
+    } else if (sess->request_type.type == OGS_PDU_SESSION_TYPE_IPV4) {
+        if (session->paa.session_type == OGS_PDU_SESSION_TYPE_IPV6) {
+            pdn_address->pdn_type = OGS_PDU_SESSION_TYPE_IPV6;
             activate_default_eps_bearer_context_request->esm_cause =
                 ESM_CAUSE_PDN_TYPE_IPV6_ONLY_ALLOWED;
             activate_default_eps_bearer_context_request->presencemask |=
                 OGS_NAS_EPS_ACTIVATE_DEFAULT_EPS_BEARER_CONTEXT_REQUEST_ESM_CAUSE_PRESENT;
         }
-    } else if (sess->request_type.type == OGS_GTP_PDN_TYPE_IPV6) {
-        if (pdn->paa.pdn_type == OGS_GTP_PDN_TYPE_IPV4) {
-            pdn_address->pdn_type = OGS_GTP_PDN_TYPE_IPV4;
+    } else if (sess->request_type.type == OGS_PDU_SESSION_TYPE_IPV6) {
+        if (session->paa.session_type == OGS_PDU_SESSION_TYPE_IPV4) {
+            pdn_address->pdn_type = OGS_PDU_SESSION_TYPE_IPV4;
             activate_default_eps_bearer_context_request->esm_cause =
                 ESM_CAUSE_PDN_TYPE_IPV4_ONLY_ALLOWED;
             activate_default_eps_bearer_context_request->presencemask |=
@@ -197,30 +198,30 @@ ogs_pkbuf_t *esm_build_activate_default_bearer_context_request(
         }
     }
 
-    if (pdn_address->pdn_type == OGS_GTP_PDN_TYPE_IPV4) {
-        pdn_address->addr = pdn->paa.addr;
+    if (pdn_address->pdn_type == OGS_PDU_SESSION_TYPE_IPV4) {
+        pdn_address->addr = session->paa.addr;
         pdn_address->length = OGS_NAS_PDU_ADDRESS_IPV4_LEN;
         ogs_debug("    IPv4");
-    } else if (pdn_address->pdn_type == OGS_GTP_PDN_TYPE_IPV6) {
+    } else if (pdn_address->pdn_type == OGS_PDU_SESSION_TYPE_IPV6) {
         memcpy(pdn_address->addr6,
-                pdn->paa.addr6+(OGS_IPV6_LEN>>1), OGS_IPV6_LEN>>1);
+                session->paa.addr6+(OGS_IPV6_LEN>>1), OGS_IPV6_LEN>>1);
         pdn_address->length = OGS_NAS_PDU_ADDRESS_IPV6_LEN;
         ogs_debug("    IPv6");
-    } else if (pdn_address->pdn_type == OGS_GTP_PDN_TYPE_IPV4V6) {
-        pdn_address->both.addr = pdn->paa.both.addr;
+    } else if (pdn_address->pdn_type == OGS_PDU_SESSION_TYPE_IPV4V6) {
+        pdn_address->both.addr = session->paa.both.addr;
         memcpy(pdn_address->both.addr6,
-                pdn->paa.both.addr6+(OGS_IPV6_LEN>>1), OGS_IPV6_LEN>>1);
+                session->paa.both.addr6+(OGS_IPV6_LEN>>1), OGS_IPV6_LEN>>1);
         pdn_address->length = OGS_NAS_PDU_ADDRESS_IPV4V6_LEN;
         ogs_debug("    IPv4v6");
     } else {
-        ogs_error("Unexpected PDN Type %u", pdn_address->pdn_type);
-        return NULL;
+        ogs_fatal("Unexpected PDN Type %u", pdn_address->pdn_type);
+        ogs_assert_if_reached();
     }
 
-    if (pdn->ambr.downlink || pdn->ambr.uplink) {
+    if (session->ambr.downlink || session->ambr.uplink) {
         activate_default_eps_bearer_context_request->presencemask |=
             OGS_NAS_EPS_ACTIVATE_DEFAULT_EPS_BEARER_CONTEXT_REQUEST_APN_AMBR_PRESENT;
-        apn_ambr_build(apn_ambr, pdn->ambr.downlink, pdn->ambr.uplink);
+        apn_ambr_build(apn_ambr, session->ambr.downlink, session->ambr.uplink);
     }
 
     if (sess->pgw_pco.presence && sess->pgw_pco.len && sess->pgw_pco.data) {
@@ -285,7 +286,7 @@ ogs_pkbuf_t *esm_build_activate_dedicated_bearer_context_request(
         OGS_NAS_EPS_ACTIVATE_DEDICATED_EPS_BEARER_CONTEXT_REQUEST;
 
     linked_ebi->eps_bearer_identity = linked_bearer->ebi;
-    eps_qos_build(eps_qos, bearer->qos.qci,
+    eps_qos_build(eps_qos, bearer->qos.index,
             bearer->qos.mbr.downlink, bearer->qos.mbr.uplink,
             bearer->qos.gbr.downlink, bearer->qos.gbr.uplink);
 
@@ -334,7 +335,7 @@ ogs_pkbuf_t *esm_build_modify_bearer_context_request(
     if (qos_presence == 1) {
         modify_eps_bearer_context_request->presencemask |=
             OGS_NAS_EPS_MODIFY_EPS_BEARER_CONTEXT_REQUEST_NEW_EPS_QOS_PRESENT;
-        eps_qos_build(new_eps_qos, bearer->qos.qci,
+        eps_qos_build(new_eps_qos, bearer->qos.index,
                 bearer->qos.mbr.downlink, bearer->qos.mbr.uplink,
                 bearer->qos.gbr.downlink, bearer->qos.gbr.uplink);
     }
@@ -389,84 +390,62 @@ ogs_pkbuf_t *esm_build_deactivate_bearer_context_request(
 }
 
 ogs_pkbuf_t *esm_build_bearer_resource_allocation_reject(
-        mme_bearer_t *bearer, ogs_nas_esm_cause_t esm_cause)
+        mme_ue_t *mme_ue, uint8_t pti, ogs_nas_esm_cause_t esm_cause)
 {
-    mme_ue_t *mme_ue = NULL;
-    mme_sess_t *sess = NULL;
-
     ogs_nas_eps_message_t message;
     ogs_nas_eps_bearer_resource_allocation_reject_t
         *bearer_resource_allocation_reject =
             &message.esm.bearer_resource_allocation_reject;
 
-    ogs_assert(bearer);
-    sess = bearer->sess;
-    ogs_assert(sess);
-    mme_ue = sess->mme_ue;
     ogs_assert(mme_ue);
+    ogs_assert(pti != OGS_NAS_PROCEDURE_TRANSACTION_IDENTITY_UNASSIGNED);
 
     ogs_debug("Bearer resource allocation reject");
     ogs_debug("    IMSI[%s] PTI[%d] Cause[%d]",
-            mme_ue->imsi_bcd, sess->pti, esm_cause);
+            mme_ue->imsi_bcd, pti, esm_cause);
 
     memset(&message, 0, sizeof(message));
-    if (!SESSION_CONTEXT_IN_ATTACH(sess)) {
-        message.h.security_header_type =
-           OGS_NAS_SECURITY_HEADER_INTEGRITY_PROTECTED_AND_CIPHERED;
-        message.h.protocol_discriminator = OGS_NAS_PROTOCOL_DISCRIMINATOR_EMM;
-    }
+    message.h.security_header_type =
+       OGS_NAS_SECURITY_HEADER_INTEGRITY_PROTECTED_AND_CIPHERED;
+    message.h.protocol_discriminator = OGS_NAS_PROTOCOL_DISCRIMINATOR_EMM;
 
     message.esm.h.eps_bearer_identity = 0;
     message.esm.h.protocol_discriminator = OGS_NAS_PROTOCOL_DISCRIMINATOR_ESM;
-    message.esm.h.procedure_transaction_identity = sess->pti;
+    message.esm.h.procedure_transaction_identity = pti;
     message.esm.h.message_type = OGS_NAS_EPS_BEARER_RESOURCE_ALLOCATION_REJECT;
 
     bearer_resource_allocation_reject->esm_cause = esm_cause;
 
-    if (SESSION_CONTEXT_IN_ATTACH(sess))
-        return ogs_nas_eps_plain_encode(&message);
-    else
-        return nas_eps_security_encode(mme_ue, &message);
+    return nas_eps_security_encode(mme_ue, &message);
 }
 
 ogs_pkbuf_t *esm_build_bearer_resource_modification_reject(
-        mme_bearer_t *bearer, ogs_nas_esm_cause_t esm_cause)
+        mme_ue_t *mme_ue, uint8_t pti, ogs_nas_esm_cause_t esm_cause)
 {
-    mme_ue_t *mme_ue = NULL;
-    mme_sess_t *sess = NULL;
-
     ogs_nas_eps_message_t message;
     ogs_nas_eps_bearer_resource_modification_reject_t
         *bearer_resource_modification_reject =
             &message.esm.bearer_resource_modification_reject;
 
-    ogs_assert(bearer);
-    sess = bearer->sess;
-    ogs_assert(sess);
-    mme_ue = sess->mme_ue;
     ogs_assert(mme_ue);
+    ogs_assert(pti != OGS_NAS_PROCEDURE_TRANSACTION_IDENTITY_UNASSIGNED);
 
     ogs_debug("Bearer resource modification reject");
     ogs_debug("    IMSI[%s] PTI[%d] Cause[%d]",
-            mme_ue->imsi_bcd, sess->pti, esm_cause);
+            mme_ue->imsi_bcd, pti, esm_cause);
 
     memset(&message, 0, sizeof(message));
-    if (!SESSION_CONTEXT_IN_ATTACH(sess)) {
-        message.h.security_header_type =
-           OGS_NAS_SECURITY_HEADER_INTEGRITY_PROTECTED_AND_CIPHERED;
-        message.h.protocol_discriminator = OGS_NAS_PROTOCOL_DISCRIMINATOR_EMM;
-    }
+    message.h.security_header_type =
+       OGS_NAS_SECURITY_HEADER_INTEGRITY_PROTECTED_AND_CIPHERED;
+    message.h.protocol_discriminator = OGS_NAS_PROTOCOL_DISCRIMINATOR_EMM;
 
     message.esm.h.eps_bearer_identity = 0;
     message.esm.h.protocol_discriminator = OGS_NAS_PROTOCOL_DISCRIMINATOR_ESM;
-    message.esm.h.procedure_transaction_identity = sess->pti;
+    message.esm.h.procedure_transaction_identity = pti;
     message.esm.h.message_type =
         OGS_NAS_EPS_BEARER_RESOURCE_MODIFICATION_REJECT;
 
     bearer_resource_modification_reject->esm_cause = esm_cause;
 
-    if (SESSION_CONTEXT_IN_ATTACH(sess))
-        return ogs_nas_eps_plain_encode(&message);
-    else
-        return nas_eps_security_encode(mme_ue, &message);
+    return nas_eps_security_encode(mme_ue, &message);
 }
