@@ -312,10 +312,12 @@ struct mme_ue_s {
     int             a_msisdn_len;
     char            a_msisdn_bcd[OGS_MAX_MSISDN_BCD_LEN+1];
 
-    mme_m_tmsi_t    *m_tmsi;
     mme_p_tmsi_t    p_tmsi;
-    ogs_nas_eps_guti_t guti;
-    bool            guti_present;
+
+    struct {
+        mme_m_tmsi_t *m_tmsi;
+        ogs_nas_eps_guti_t guti;
+    } current, next;
 
     uint32_t        mme_s11_teid;   /* MME-S11-TEID is derived from INDEX */
     uint32_t        sgw_s11_teid;   /* SGW-S11-TEID is received from SGW */
@@ -687,6 +689,7 @@ enb_ue_t *enb_ue_find_by_mme_ue_s1ap_id(uint32_t mme_ue_s1ap_id);
 enb_ue_t *enb_ue_cycle(enb_ue_t *enb_ue);
 
 void mme_ue_new_guti(mme_ue_t *mme_ue);
+void mme_ue_confirm_guti(mme_ue_t *mme_ue);
 
 mme_ue_t *mme_ue_add(enb_ue_t *enb_ue);
 void mme_ue_remove(mme_ue_t *mme_ue);
