@@ -29,7 +29,7 @@ extern "C" {
 int sgwc_gtp_open(void);
 void sgwc_gtp_close(void);
 
-void sgwc_gtp_send_downlink_data_notification(
+int sgwc_gtp_send_downlink_data_notification(
     uint8_t cause_value, sgwc_bearer_t *bearer);
 
 #ifdef __cplusplus
