@@ -270,7 +270,7 @@ void sgwc_pfcp_state_associated(ogs_fsm_t *s, sgwc_event_t *e)
         }
         break;
     case SGWC_EVT_SXA_NO_HEARTBEAT:
-        ogs_warn("No Heartbeat from UPF [%s]:%d",
+        ogs_warn("No Heartbeat from SGW-U [%s]:%d",
                     OGS_ADDR(addr, buf), OGS_PORT(addr));
         OGS_FSM_TRAN(s, sgwc_pfcp_state_will_associate);
         break;
