@@ -245,7 +245,7 @@ void sgwu_pfcp_state_associated(ogs_fsm_t *s, sgwu_event_t *e)
         }
         break;
     case SGWU_EVT_SXA_NO_HEARTBEAT:
-        ogs_warn("No Heartbeat from SGWU [%s]:%d",
+        ogs_warn("No Heartbeat from SGW-C [%s]:%d",
                     OGS_ADDR(addr, buf), OGS_PORT(addr));
         OGS_FSM_TRAN(s, sgwu_pfcp_state_will_associate);
         break;
