@@ -290,7 +290,7 @@ static void bearer_epc_timeout(ogs_pfcp_xact_t *xact, void *data)
     }
 }
 
-void smf_5gc_pfcp_send_session_establishment_request(
+int smf_5gc_pfcp_send_session_establishment_request(
         smf_sess_t *sess, ogs_sbi_stream_t *stream)
 {
     int rv;
@@ -306,18 +306,20 @@ void smf_5gc_pfcp_send_session_establishment_request(
     h.seid = sess->upf_n4_seid;
 
     n4buf = smf_n4_build_session_establishment_request(h.type, sess);
-    ogs_expect_or_return(n4buf);
+    ogs_expect_or_return_val(n4buf, OGS_ERROR);
 
     xact = ogs_pfcp_xact_local_create(
             sess->pfcp_node, &h, n4buf, sess_5gc_timeout, sess);
-    ogs_expect_or_return(xact);
+    ogs_expect_or_return_val(xact, OGS_ERROR);
     xact->assoc_stream = stream;
 
     rv = ogs_pfcp_xact_commit(xact);
     ogs_expect(rv == OGS_OK);
+
+    return rv;
 }
 
-void smf_5gc_pfcp_send_session_modification_request(
+int smf_5gc_pfcp_send_session_modification_request(
         smf_sess_t *sess, ogs_sbi_stream_t *stream,
         uint64_t flags, ogs_time_t duration)
 {
@@ -335,23 +337,27 @@ void smf_5gc_pfcp_send_session_modification_request(
     h.seid = sess->upf_n4_seid;
 
     n4buf = smf_n4_build_session_modification_request(h.type, sess, flags);
-    ogs_expect_or_return(n4buf);
+    ogs_expect_or_return_val(n4buf, OGS_ERROR);
 
     xact = ogs_pfcp_xact_local_create(
             sess->pfcp_node, &h, n4buf, sess_5gc_timeout, sess);
-    ogs_expect_or_return(xact);
+    ogs_expect_or_return_val(xact, OGS_ERROR);
     xact->assoc_stream = stream;
     xact->modify_flags = flags | OGS_PFCP_MODIFY_SESSION;
 
     if (duration) {
         ogs_pfcp_xact_delayed_commit(xact, duration);
+
+        return OGS_OK;
     } else {
         rv = ogs_pfcp_xact_commit(xact);
         ogs_expect(rv == OGS_OK);
+
+        return rv;
     }
 }
 
-void smf_5gc_pfcp_send_qos_flow_modification_request(smf_bearer_t *qos_flow,
+int smf_5gc_pfcp_send_qos_flow_modification_request(smf_bearer_t *qos_flow,
         ogs_sbi_stream_t *stream, uint64_t flags)
 {
     int rv;
@@ -369,20 +375,22 @@ void smf_5gc_pfcp_send_qos_flow_modification_request(smf_bearer_t *qos_flow,
     h.seid = sess->upf_n4_seid;
 
     n4buf = smf_n4_build_qos_flow_modification_request(h.type, qos_flow, flags);
-    ogs_expect_or_return(n4buf);
+    ogs_expect_or_return_val(n4buf, OGS_ERROR);
 
     xact = ogs_pfcp_xact_local_create(
             sess->pfcp_node, &h, n4buf, qos_flow_5gc_timeout, qos_flow);
-    ogs_expect_or_return(xact);
+    ogs_expect_or_return_val(xact, OGS_ERROR);
 
     xact->assoc_stream = stream;
     xact->modify_flags = flags;
 
     rv = ogs_pfcp_xact_commit(xact);
     ogs_expect(rv == OGS_OK);
+
+    return rv;
 }
 
-void smf_5gc_pfcp_send_session_deletion_request(
+int smf_5gc_pfcp_send_session_deletion_request(
         smf_sess_t *sess, ogs_sbi_stream_t *stream, int trigger)
 {
     int rv;
@@ -399,19 +407,21 @@ void smf_5gc_pfcp_send_session_deletion_request(
     h.seid = sess->upf_n4_seid;
 
     n4buf = smf_n4_build_session_deletion_request(h.type, sess);
-    ogs_expect_or_return(n4buf);
+    ogs_expect_or_return_val(n4buf, OGS_ERROR);
 
     xact = ogs_pfcp_xact_local_create(
             sess->pfcp_node, &h, n4buf, sess_5gc_timeout, sess);
-    ogs_expect_or_return(xact);
+    ogs_expect_or_return_val(xact, OGS_ERROR);
     xact->assoc_stream = stream;
     xact->delete_trigger = trigger;
 
     rv = ogs_pfcp_xact_commit(xact);
     ogs_expect(rv == OGS_OK);
+
+    return rv;
 }
 
-void smf_epc_pfcp_send_session_establishment_request(
+int smf_epc_pfcp_send_session_establishment_request(
         smf_sess_t *sess, void *gtp_xact)
 {
     int rv;
@@ -426,20 +436,22 @@ void smf_epc_pfcp_send_session_establishment_request(
     h.seid = sess->upf_n4_seid;
 
     n4buf = smf_n4_build_session_establishment_request(h.type, sess);
-    ogs_expect_or_return(n4buf);
+    ogs_expect_or_return_val(n4buf, OGS_ERROR);
 
     xact = ogs_pfcp_xact_local_create(
             sess->pfcp_node, &h, n4buf, sess_epc_timeout, sess);
-    ogs_expect_or_return(xact);
+    ogs_expect_or_return_val(xact, OGS_ERROR);
 
     xact->epc = true; /* EPC PFCP transaction */
     xact->assoc_xact = gtp_xact;
 
     rv = ogs_pfcp_xact_commit(xact);
     ogs_expect(rv == OGS_OK);
+
+    return rv;
 }
 
-void smf_epc_pfcp_send_bearer_modification_request(
+int smf_epc_pfcp_send_bearer_modification_request(
         smf_bearer_t *bearer, uint64_t flags)
 {
     int rv;
@@ -457,20 +469,22 @@ void smf_epc_pfcp_send_bearer_modification_request(
     h.seid = sess->upf_n4_seid;
 
     n4buf = smf_n4_build_qos_flow_modification_request(h.type, bearer, flags);
-    ogs_expect_or_return(n4buf);
+    ogs_expect_or_return_val(n4buf, OGS_ERROR);
 
     xact = ogs_pfcp_xact_local_create(
             sess->pfcp_node, &h, n4buf, bearer_epc_timeout, bearer);
-    ogs_expect_or_return(xact);
+    ogs_expect_or_return_val(xact, OGS_ERROR);
 
     xact->epc = true; /* EPC PFCP transaction */
     xact->modify_flags = flags;
 
     rv = ogs_pfcp_xact_commit(xact);
     ogs_expect(rv == OGS_OK);
+
+    return rv;
 }
 
-void smf_epc_pfcp_send_session_deletion_request(
+int smf_epc_pfcp_send_session_deletion_request(
         smf_sess_t *sess, void *gtp_xact)
 {
     int rv;
@@ -485,20 +499,22 @@ void smf_epc_pfcp_send_session_deletion_request(
     h.seid = sess->upf_n4_seid;
 
     n4buf = smf_n4_build_session_deletion_request(h.type, sess);
-    ogs_expect_or_return(n4buf);
+    ogs_expect_or_return_val(n4buf, OGS_ERROR);
 
     xact = ogs_pfcp_xact_local_create(
             sess->pfcp_node, &h, n4buf, sess_epc_timeout, sess);
-    ogs_expect_or_return(xact);
+    ogs_expect_or_return_val(xact, OGS_ERROR);
 
     xact->epc = true; /* EPC PFCP transaction */
     xact->assoc_xact = gtp_xact;
 
     rv = ogs_pfcp_xact_commit(xact);
     ogs_expect(rv == OGS_OK);
+
+    return rv;
 }
 
-void smf_pfcp_send_session_report_response(
+int smf_pfcp_send_session_report_response(
         ogs_pfcp_xact_t *xact, smf_sess_t *sess, uint8_t cause)
 {
     int rv;
@@ -512,11 +528,13 @@ void smf_pfcp_send_session_report_response(
     h.seid = sess->upf_n4_seid;
 
     sxabuf = ogs_pfcp_build_session_report_response(h.type, cause);
-    ogs_expect_or_return(sxabuf);
+    ogs_expect_or_return_val(sxabuf, OGS_ERROR);
 
     rv = ogs_pfcp_xact_update_tx(xact, &h, sxabuf);
-    ogs_expect_or_return(rv == OGS_OK);
+    ogs_expect_or_return_val(rv == OGS_OK, OGS_ERROR);
 
     rv = ogs_pfcp_xact_commit(xact);
     ogs_expect(rv == OGS_OK);
+
+    return rv;
 }
