@@ -80,26 +80,9 @@ void smf_state_operational(ogs_fsm_t *s, smf_event_t *e)
 
     switch (e->id) {
     case OGS_FSM_ENTRY_SIG:
-        rv = smf_gtp_open();
-        if (rv != OGS_OK) {
-            ogs_fatal("Can't establish S11-GTP path");
-        }
-
-        rv = smf_pfcp_open();
-        if (rv != OGS_OK) {
-            ogs_fatal("Can't establish N4-PFCP path");
-        }
-
-        rv = smf_sbi_open();
-        if (rv != OGS_OK) {
-            ogs_fatal("Can't establish SBI path");
-        }
         break;
 
     case OGS_FSM_EXIT_SIG:
-        smf_gtp_close();
-        smf_pfcp_close();
-        smf_sbi_close();
         break;
 
     case SMF_EVT_S5C_MESSAGE:
@@ -535,6 +518,12 @@ void smf_state_operational(ogs_fsm_t *s, smf_event_t *e)
 
             sess = (smf_sess_t *)sbi_xact->sbi_object;
             ogs_assert(sess);
+
+            e->sbi.data = sbi_xact->assoc_stream;
+            e->sbi.state = sbi_xact->state;
+
+            ogs_sbi_xact_remove(sbi_xact);
+
             sess = smf_sess_cycle(sess);
             ogs_assert(sess);
             smf_ue = sess->smf_ue;
@@ -545,10 +534,6 @@ void smf_state_operational(ogs_fsm_t *s, smf_event_t *e)
 
             e->sess = sess;
             e->sbi.message = &sbi_message;
-            e->sbi.data = sbi_xact->assoc_stream;
-            e->sbi.state = sbi_xact->state;
-
-            ogs_sbi_xact_remove(sbi_xact);
 
             ogs_fsm_dispatch(&sess->sm, e);
             if (OGS_FSM_CHECK(&sess->sm, smf_gsm_state_exception)) {
