@@ -36,7 +36,6 @@ void udm_context_init(void)
 
     ogs_log_install_domain(&__udm_log_domain, "udm", ogs_core()->log.level);
 
-    /* Allocate TWICE the pool to check if maximum number of gNBs is reached */
     ogs_pool_init(&udm_ue_pool, ogs_app()->max.ue);
 
     ogs_list_init(&self.udm_ue_list);
@@ -230,3 +229,14 @@ udm_ue_t *udm_ue_cycle(udm_ue_t *udm_ue)
 {
     return ogs_pool_cycle(&udm_ue_pool, udm_ue);
 }
+
+void udm_ue_select_nf(udm_ue_t *udm_ue, OpenAPI_nf_type_e nf_type)
+{
+    ogs_assert(udm_ue);
+    ogs_assert(nf_type);
+
+    if (nf_type == OpenAPI_nf_type_NRF)
+        ogs_sbi_select_nrf(&udm_ue->sbi, udm_nf_state_registered);
+    else
+        ogs_sbi_select_first_nf(&udm_ue->sbi, nf_type, udm_nf_state_registered);
+}
