@@ -27,15 +27,15 @@ extern "C" {
 #endif
 
 bool udm_nudm_ueau_handle_get(
-    udm_ue_t *udm_ue, ogs_sbi_session_t *session, ogs_sbi_message_t *recvmsg);
+    udm_ue_t *udm_ue, ogs_sbi_stream_t *stream, ogs_sbi_message_t *recvmsg);
 bool udm_nudm_ueau_handle_result_confirmation_inform(
-    udm_ue_t *udm_ue, ogs_sbi_session_t *session, ogs_sbi_message_t *message);
+    udm_ue_t *udm_ue, ogs_sbi_stream_t *stream, ogs_sbi_message_t *message);
 
 bool udm_nudm_uecm_handle_registration(
-    udm_ue_t *udm_ue, ogs_sbi_session_t *session, ogs_sbi_message_t *message);
+    udm_ue_t *udm_ue, ogs_sbi_stream_t *stream, ogs_sbi_message_t *message);
 
 bool udm_nudm_sdm_handle_subscription_provisioned(
-    udm_ue_t *udm_ue, ogs_sbi_session_t *session, ogs_sbi_message_t *recvmsg);
+    udm_ue_t *udm_ue, ogs_sbi_stream_t *stream, ogs_sbi_message_t *recvmsg);
 
 #ifdef __cplusplus
 }
