@@ -171,11 +171,18 @@ ogs_sbi_request_t *udm_nudr_dr_build_query_subscription_provisioned(
     CASE(OGS_SBI_RESOURCE_NAME_SM_DATA)
         if (recvmsg->param.dnn)
             sendmsg.param.dnn = recvmsg->param.dnn;
-        if (recvmsg->param.s_nssai_presence) {
-            sendmsg.param.s_nssai_presence = true;
-            memcpy(&sendmsg.param.s_nssai,
-                    &recvmsg->param.s_nssai, sizeof(recvmsg->param.s_nssai));
+        if (recvmsg->param.single_nssai_presence) {
+            sendmsg.param.single_nssai_presence = true;
+            memcpy(&sendmsg.param.s_nssai, &recvmsg->param.s_nssai,
+                    sizeof(sendmsg.param.s_nssai));
         }
+        break;
+
+    CASE(OGS_SBI_RESOURCE_NAME_SMF_SELECT_DATA)
+        sendmsg.h.resource.component[4] =
+            (char *)OGS_SBI_RESOURCE_NAME_SMF_SELECTION_SUBSCRIPTION_DATA;
+        break;
+
     DEFAULT
     END
 
