@@ -20,7 +20,7 @@
 #ifndef UDR_SBI_PATH_H
 #define UDR_SBI_PATH_H
 
-#include "context.h"
+#include "nnrf-build.h"
 
 #ifdef __cplusplus
 extern "C" {
@@ -29,6 +29,8 @@ extern "C" {
 int udr_sbi_open(void);
 void udr_sbi_close(void);
 
+void udr_nnrf_nfm_send_nf_register(ogs_sbi_nf_instance_t *nf_instance);
+
 #ifdef __cplusplus
 }
 #endif
